Learn R Programming

Luminescence (version 0.2.1)

Calc_FadingCorr: Apply a fading correction according to Huntley & Lamothe (2001) for a given g-value.

Description

This function runs the itrerations that are needed to calculate the corrected age including the error for a given g-value according to Huntley & Lamothe (2001).

Usage

Calc_FadingCorr(g_value, tc, age.faded, n.MCruns = 500)

Arguments

g_value
vector (required): g-value and error obtained from separate fading measurements (see example)
tc
numeric (required): time in seconds (time between irradiation and the prompt measurement, cf. Huntely & Lamothe 2001).
age.faded
numeric vector (required): uncorrected age with error in ka (see example)
n.MCruns
integer (with default): number of Monte Carlo simulation runs for error estimation

Value

  • A data.frame containing the fading-corrected age is returned.

Details

The error of the fading-corrected age is determined using a Monte Carlo simulation approach. Hugh values for n.MCruns will significantly increase the computation time.

References

Huntley, D.J. & Lamothe, M., 2001. Ubiquity of anomalous fading in K-feldspars and the measurement and correction for it in optical dating. Canadian Journal of Earth Sciences, 38, pp. 1093-1106.

See Also

##

Examples

Run this code
Calc_FadingCorr(g_value = c(3.3,0.03), tc = 752, age.faded = c(100,10))

Run the code above in your browser using DataLab