Learn R Programming

Luminescence (version 0.1.8)

Calc_OSLLxTxRatio: Calculate Lx/Tx ratio for OSL curves.

Description

Calculate Lx/Tx ratios from two given OSL curves.

Usage

Calc_OSLLxTxRatio(Lx.data,Tx.data,
                  signal.integral,
                  background.integral)

Arguments

Lx.data
data.frame (required): requires an OSL shine down curve (x=time,y=counts)
Tx.data
data.frame (optional): requires an OSL shine down curve (x=time,y=counts). If no input is given the Tx.data will be treated as NA and no Lx/Tx ratio is calculated.
signal.integral
vector (required): requires a vector with the bounds for the signal integral.
background.integral
vector (required): requires a vector with the bounds for the background integral.

Value

Details

The integrity of the chosen values for the signal and background integral are checked by the function. If a vector is given as input instead of a data.frame an artifical data.frame is produced. The error calculation is done according Galbraith (2002).

References

Duller, G., 2007. Analyst.

Galbraith, R.F., 2002. A note on the variance of a background-corrected OSL count. Ancient TL, 20 (2), 49-51.

See Also

Analyse_SAR.OSLdata, plot_GrowthCurve

Examples

Run this code
##load data
data(ExampleData.LxTxOSLData)

##calculate Lx/Tx ratio
results<-Calc_OSLLxTxRatio(Lx.data,Tx.data,signal.integral=c(1:2),background.integral=c(85:100))
print(results)

Run the code above in your browser using DataLab