RLum.Data.Image-class: Class '"RLum.Data.Image"'

RLum.Data.Image-classR Documentation

Class "RLum.Data.Image"

Description

Class for representing luminescence image data (TL/OSL/RF). Such data are for example produced by function read_SPE2R.

Slots

recordType

Object of class character containing the type of the curve (e.g. "OSL image", "TL image").

curveType

Object of class character containing curve type, allowed values are measured or predefined

data

Object of class array containing image data.

info

Object of class list containing further meta information objects

Objects from the class

Objects can be created by calls of the form set_RLum("RLum.Data.Image", ...).

Class version

0.5.1

Note

The class should only contain data for a set of images. For additional elements the slot info can be used.

Author(s)

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

See Also

RLum, RLum.Data, plot_RLum, read_SPE2R, read_TIFF2R

Examples


showClass("RLum.Data.Image")

##create empty RLum.Data.Image object
set_RLum(class = "RLum.Data.Image")


Luminescence documentation built on Sept. 18, 2026, 9:07 a.m.