RLum.Data.Spectrum-class: Class '"RLum.Data.Spectrum"'

RLum.Data.Spectrum-classR Documentation

Class "RLum.Data.Spectrum"

Description

Class for representing luminescence spectra data (TL/OSL/RF).

Slots

recordType

Object of class character containing the type of the curve (e.g. "TL" or "OSL")

curveType

Object of class character containing curve type, allowed values are "measured" or "predefined"

data

Object of class matrix containing spectrum (count) values. Row labels indicate wavelength/pixel values, column labels are temperature or time values.

info

Object of class list containing further meta information objects

Objects from the Class

Objects can be created by calls of the form set_RLum("RLum.Data.Spectrum", ...).

Class version

0.5.2

Note

The class should only contain data for a single spectra data set. For additional elements the slot info can be used. Objects from this class are automatically created by, e.g., read_XSYG2R

Author(s)

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

See Also

RLum, RLum.Data, plot_RLum

Examples


showClass("RLum.Data.Spectrum")

##show example data
data(ExampleData.XSYG, envir = environment())
TL.Spectrum

##show data matrix
get_RLum(TL.Spectrum)

##plot spectrum
## Not run: 
plot_RLum(TL.Spectrum)

## End(Not run)


Luminescence documentation built on Sept. 18, 2026, 9:07 a.m.