Risoe.BINfileData2RLum.Analysis: Convert Risoe.BINfileData object to an RLum.Analysis object

View source: R/Risoe.BINfileData2RLum.Analysis.R

Risoe.BINfileData2RLum.AnalysisR Documentation

Convert Risoe.BINfileData object to an RLum.Analysis object

Description

Converts values from one specific position of a Risoe.BINfileData object to an RLum.Analysis object.

The RLum.Analysis object requires a set of curves for specific further protocol analyses. However, the Risoe.BINfileData usually contains a set of curves for different aliquots and different protocol types that may be mixed up. Therefore, a conversion is needed.

Usage

Risoe.BINfileData2RLum.Analysis(
  object,
  pos = NULL,
  grain = NULL,
  run = NULL,
  set = NULL,
  ltype = NULL,
  dtype = NULL,
  protocol = "unknown",
  keep.empty = TRUE,
  txtProgressBar = FALSE
)

Arguments

object

Risoe.BINfileData (required): object to convert.

pos

numeric (optional): position number of the Risoe.BINfileData object for which the curves are converted into an RLum.Analysis object. If length(pos) > 1, a list of RLum.Analysis objects is returned. If nothing is provided every position will be converted. If the position is not valid NULL is returned.

grain

vector, numeric (optional): grain number from the measurement to limit the converted data set (e.g., grain = 1:48). Please be aware that this option may lead to unwanted effects, as the output is strictly limited to the chosen grain number for all position numbers. Invalid grain numbers are skipped with a warning. Records with NA as grain are always included, as some readers report NA instead of a grain number.

run

vector, numeric (optional): run number from the measurement to limit the converted data set (e.g., run = 1:48).

set

vector, numeric (optional): set number from the measurement to limit the converted data set (e.g., set = 1:48).

ltype

vector, character (optional): curve type to limit the converted data. Commonly allowed values are: "IRSL", "OSL", "TL", "RIR", "RBR" and "USER" (see also Risoe.BINfileData).

dtype

vector, character (optional): data type to limit the converted data. Commonly allowed values are listed in Risoe.BINfileData.

protocol

character (optional): protocol type to be set in the analysis object. This value may be used by subsequent analysis functions.

keep.empty

logical (with default): If TRUE (default) an RLum.Analysis object is returned even if it does not contain any records. Set to FALSE to discard all empty objects.

txtProgressBar

logical (with default): enable/disable the progress bar. The progress bar is disabled automatically if fewer than two positions are converted.

Value

Returns an RLum.Analysis object if exactly one position and one grain number were converted, and a list of RLum.Analysis objects (one per position/grain combination) otherwise. Returns NULL if no valid position is provided or if all objects are discarded by keep.empty = FALSE.

Function version

0.4.3

How to cite

Kreutzer, S., 2026. Risoe.BINfileData2RLum.Analysis(): Convert Risoe.BINfileData object to an RLum.Analysis object. Function version 0.4.3. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/

Note

The protocol argument of the RLum.Analysis object is set to 'unknown' if not stated otherwise.

Author(s)

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

See Also

Risoe.BINfileData, RLum.Analysis, read_BIN2R

Examples


##load data
data(ExampleData.BINfileData, envir = environment())

##convert values for position 1
Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos = 1)


Luminescence documentation built on Sept. 18, 2026, 9:07 a.m.