View source: R/analyse_Al2O3C_CrossTalk.R
| analyse_Al2O3C_CrossTalk | R Documentation |
The function provides the analysis of cross-talk measurements on a FI lexsyg SMART reader using Al2O3:C chips.
analyse_Al2O3C_CrossTalk(
object,
signal_integral = NULL,
integral_input = c("channel", "measurement"),
dose_points = c(0, 4),
recordType = "OSL (UVVIS)",
irradiation_time_correction = NULL,
method_control = NULL,
plot = TRUE,
...
)
object |
RLum.Analysis or list (required): measurement input |
signal_integral |
numeric (optional): signal integral, used for the signal and the background. If nothing is provided, the full range is used. |
integral_input |
character (with default):
input type for |
dose_points |
numeric (with default): vector with dose points, if dose points are repeated, only the general pattern needs to be provided. Default values follow the suggestions made by Kreutzer et al., 2018. |
recordType |
character (with default):
input curve selection, which is passed to get_RLum. To deactivate the
automatic selection set the argument to |
irradiation_time_correction |
numeric or RLum.Results (optional): information on the used irradiation time correction obtained by another experiment. |
method_control |
list (optional): optional parameters to control the calculation. See details for further explanations. |
plot |
logical (with default): enable/disable the plot output. |
... |
further arguments and graphical parameters to control the plot
output. Supported are: |
Function returns results numerically and graphically:
———————————–
[ NUMERICAL OUTPUT ]
———————————–
RLum.Results-object
slot: @data
| Element | Type | Description |
$data | data.frame | summed apparent dose table |
$data_full | data.frame | full apparent dose table |
$fit | lm | the linear model obtained from fitting |
$col.seq | numeric | the used colour vector |
slot: @info
The original function call
————————
[ PLOT OUTPUT ]
————————
An overview of the obtained apparent dose values
0.1.5
Kreutzer, S., 2026. analyse_Al2O3C_CrossTalk(): Al2O3:C Reader Cross-Talk Analysis. Function version 0.1.5. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
Kreutzer, S., Martin, L., Guérin, G., Tribolo, C., Selva, P., Mercier, N., 2018. Environmental Dose Rate Determination Using a Passive Dosimeter: Techniques and Workflow for alpha-Al2O3:C Chips. Geochronometria 45, 56-67. doi: 10.1515/geochr-2015-0086
analyse_Al2O3C_ITC
##load data
data(ExampleData.Al2O3C, envir = environment())
##run analysis
analyse_Al2O3C_CrossTalk(data_CrossTalk)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.