View source: R/analyse_SAR.NCF.R
| analyse_SAR.NCF | R Documentation |
The function computes the natural sensitivity correction factor (NCF) for
the assessment of single aliquot regeneration based palaeodoses. This allows
to produce D_e values that account for sensitivity changes that
may occur during the preheat and readout of the natural OSL.
analyse_SAR.NCF(object, TL_peak_range = 15, method_control = NULL, ...)
object |
RLum.Analysis or list of RLum.Analysis objects (required): input object containing data for analysis. If a list is provided the functions tries to iterate over each element in the list. |
TL_peak_range |
numeric (with default): size of the integration window in deg. C on each side of the identified peak. |
method_control |
list (optional): parameters to control the peak-finding step (see Details). |
... |
further arguments that will be passed to
fit_DoseResponseCurve, plot_DoseResponseCurve
or calc_OSLLxTxRatio (the latter only supports
Note: |
This function is a wrapper around analyse_SAR.CWOSL: it works in a similar way, but corrects the natural OSL signal according to Singhvi et al. (2011) and by implementing the MatLab code reported in Kaushal et al. (2022).
The NCF protocol modifies the standard SAR protocol by adding a small dose before the readout of the natural signal; the corresponding 110 deg. C TL peak in quartz is monitored and compared to the TL peak recorded during the typical cutheat measurement. The additional dose used for the NCF TL curves is subtracted automatically. The published NCF sequence structure must be followed, otherwise the correction will not work.
The natural sensitivity correction factor (NCF) is measured as the ratio of the 110 deg. C TL peaks before and after the measurement of natural OSL, accounting for an integration range around the peak, typically 15 deg. C or the full width at half maximum (FWHM).
The TL peaks are found automatically by finding the position with highest counts below 160 deg. C (after some smoothing has been applied to the counts data) for each of the two TL curves.
The peak search parameters can be controlled via the method_control
argument. If used, this must be a list with one or more of the following
named arguments (e.g. method_control = list(search.threshold.degrees = 130)):
peak.temperature: this can be used to set the temperature of the TL peak
manually; if set to NULL (default), the peak is found automatically
search.threshold.degrees: threshold in deg. C below which the peak
is searched (160 by default); this is ignored if peak.temperature is
not NULL
The identified TL curves and the chosen signal integral are shown in the graphical output.
Plots (optional) and an RLum.Results object is returned containing the following elements:
| DATA.OBJECT | TYPE | DESCRIPTION |
..$data : | data.frame | Table with corrected D_e values |
..$LnLxTnTx.table : | data.frame | Corrected LnLxTnTx values |
..$rejection.criteria : | data.frame | Rejection criteria |
..$Formula : | list | Function used for fitting of the dose response curve |
..$data_uncor : | data.frame | Table with the uncorrected data |
..$LnLxTnTx.table_uncor : | data.frame | Uncorrected LnLxTnTx values |
..$NCF_settings : | list | Setting used for TL peak finding |
This output is similar to the output of analyse_SAR.CWOSL extended by a few more elements.
0.1.1
Colombo, M., Kreutzer, S., 2026. analyse_SAR.NCF(): Compute SAR palaeodoses using natural sensitivity correction (NCF). Function version 0.1.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
This function is a beta version.
Marco Colombo, Institute of Geography, Heidelberg University (Germany)
Sebastian Kreutzer, LIAG Institute for Applied Geophysics (Germany)
, RLum Developer Team
Kaushal, R.K., Chauhan, N., Singhvi, A.K., 2022. Luminescence dating of quartz: A MATLAB-based program for computation of SAR paleodoses using natural sensitivity correction (NCF). Ancient TL, 40 (2), 1-7. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.26034/la.atl.2022.561")}
Singhvi, A.K., Stokes, S.C., Chauhan, N., Nagar, Y.C., Jaiwal, M.K., 2011. Changes in natural OSL sensitivity during single aliquot regeneration procedure and their implications for equivalent dose determination. Geochronometria, 38 (3), 231-241. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2478/s13386-011-0028-3")}
analyse_SAR.CWOSL, fit_DoseResponseCurve
## Load example data
file <- system.file("extdata/NCF.binx", package = "Luminescence")
ncf <- read_BIN2R(file, fastForward = TRUE)
results <- analyse_SAR.NCF(
object = ncf,
signal_integral = 1:2,
background_integral = 100:250,
dose_rate_source = 0.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.