View source: R/analyse_portableOSL.R
| analyse_portableOSL | R Documentation |
The function analyses CW-OSL curve data produced by a SUERC portable OSL reader and produces a combined plot of OSL/IRSL signal intensities, OSL/IRSL depletion ratios and the IRSL/OSL ratio.
analyse_portableOSL(
object,
signal_integral = NULL,
integral_input = c("channel", "measurement"),
invert = FALSE,
normalise = FALSE,
mode = c("profile", "surface"),
coord = NULL,
plot = TRUE,
...
)
object |
RLum.Analysis (required): object produced by read_PSL2R. The input can be a list of such objects, in which case each input is treated as a separate sample and the results are merged. |
signal_integral |
numeric (required):
vector specifying the range of channels used to calculate the OSL/IRSL
signal. It can be provided as a vector of length 2 such as |
integral_input |
character (with default):
input type for |
invert |
logical (with default):
whether the data should be plotted in reverse order ( |
normalise |
logical (with default): whether the OSL/IRSL signals should be normalised to the mean of all corresponding data curves. |
mode |
character (with default):
analysis mode, one of |
coord |
list matrix (optional): a list or a 2-column matrix
with the x and y coordinates for the sampling positions in meters (m),
of the same length as the number of samples measured. For example, the
coordinates for one sample could be |
plot |
logical (with default): enable/disable the plot output. |
... |
other parameters to be passed to modify the plot output.
Supported are |
This function only works with RLum.Analysis objects produced by read_PSL2R.
It further assumes (or rather requires) an equal amount of OSL and IRSL curves that
are pairwise combined for calculating the IRSL/OSL ratio.
For calculating the depletion ratios, the cumulative signal of the last n
channels (same number of channels as specified by signal_integral) is
divided by cumulative signal of the first n channels (signal_integral).
Note: The function assumes the following sequence pattern:
DARK COUNT, IRSL, DARK COUNT, BSL, DARK COUNT. Therefore, the
total number of curves in the input object must be a multiple of 5, and
there must be 3 DARK_COUNT records for each IRSL/BSL pair. If a different
sequence was used, the function will produce an error.
Signal processing
The function processes the signals as follows: BSL and IRSL signals are
extracted using the chosen signal integral, dark counts are taken in full.
Working with coordinates Usually samples are taken from a profile with a certain stratigraphy. In the past, the function calculated an index. Currently, you have two ways of passing on xy-coordinates to the function:
(1) Add coordinates to the sample name during measurement. The form is rather
strict and has to follow the scheme _x:<number>|y:<number>. Example:
sample_x:0.2|y:0.4.
(2) Alternatively, you can provide a list or matrix with the (x, y)
coordinates of each sample in meters (m) using the coord argument:
Example: coord = list(c(0.2, 1), c(0.3,1.2))
If in your profile the x-coordinates were not measured, x should be set to 0. Note that, in such case, a surface plot cannot be produced.
Returns an S4 RLum.Results object with the following elements:
$data
.. $summary: data.frame with the results
.. $data: list with the RLum.Analysis objects
.. $args: list the input arguments
0.1.5
Burow, C., Kreutzer, S., Colombo, M., 2026. analyse_portableOSL(): Analyse portable CW-OSL measurements. Function version 0.1.5. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Christoph Burow, University of Cologne (Germany)
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Marco Colombo, Institute of Geography, Heidelberg University (Germany)
, RLum Developer Team
RLum.Analysis, RLum.Data.Curve, read_PSL2R
## example profile plot
# (1) load example data set
data("ExampleData.portableOSL", envir = environment())
# (2) merge and plot all RLum.Analysis objects
merged <- merge_RLum(ExampleData.portableOSL)
plot_RLum(
object = merged,
combine = TRUE,
records_max = 5,
legend.pos = "outside")
merged
# (3) analyse and plot
results <- analyse_portableOSL(
merged,
signal_integral = 1:5,
invert = FALSE,
normalise = TRUE)
get_RLum(results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.