| bin_RLum.Data | R Documentation |
The function provides a generalised access point for specific RLum.Data objects. Depending on the input object, the corresponding function will be selected.
bin_RLum.Data(object, ...)
## S4 method for signature 'RLum.Data.Curve'
bin_RLum.Data(object, bin_size = 2)
## S4 method for signature 'RLum.Data.Spectrum'
bin_RLum.Data(object, bin_size.col = 1, bin_size.row = 1)
object |
RLum.Data (required):
S4 object of class |
... |
further arguments passed to the specific class method |
bin_size |
integer (with default):
number of channels used for each bin, e.g. |
bin_size.col |
integer (with default):
number of channels used for each bin, e.g. |
bin_size.row |
integer (with default):
number of channels used for each bin, e.g. |
An object of the same type as the input provided after binning is applied.
bin_RLum.Data(RLum.Data.Curve): Allows binning of RLum.Data.Curve data.
bin_RLum.Data(RLum.Data.Spectrum): Allows binning of RLum.Data.Spectrum data. Count values and values on the
x-axis are summed up; for wavelength/energy values, the mean is calculated.
0.2.0
Kreutzer, S., 2026. bin_RLum.Data(): Channel binning for RLum.Data-class objects. Function version 0.2.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Currently only RLum.Data objects of class RLum.Data.Curve
and RLum.Data.Spectrum are supported.
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum.Data.Curve, RLum.Data.Spectrum
## load example data
data(ExampleData.CW_OSL_Curve, envir = environment())
## create RLum.Data.Curve object from this example
curve <-
set_RLum(
class = "RLum.Data.Curve",
recordType = "OSL",
data = as.matrix(ExampleData.CW_OSL_Curve)
)
## plot data without and with 2 and 4 channel binning
plot_RLum(curve)
plot_RLum(bin_RLum.Data(curve, bin_size = 2))
plot_RLum(bin_RLum.Data(curve, bin_size = 4))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.