| calc_gSGC | R Documentation |
The function computes De value and De value error using the global standardised growth curve (gSGC) assumption proposed by Li et al., 2015 for OSL dating of sedimentary quartz.
calc_gSGC(
data,
gSGC.type = c("0-250", "0-450"),
gSGC.parameters = NULL,
n.MC = 100,
verbose = TRUE,
plot = TRUE,
...
)
data |
data.frame (required):
input data the following columns five columns in the given order:
|
gSGC.type |
character (with default):
function parameters to use for the iteration procedure, either |
gSGC.parameters |
list (optional):
option to provide own function parameters used for fitting as named list.
Nomenclature follows Li et al., 2015, i.e. |
n.MC |
integer (with default): number of Monte Carlo simulation runs for error estimation, see details. |
verbose |
logical (with default): enable/disable output to the terminal. |
plot |
logical (with default): enable/disable the plot output. |
... |
parameters will be passed to the plot output |
The error of the De value is determined using a Monte Carlo simulation approach.
Solving of the equation is realised using uniroot.
Large values for n.MC will significantly increase the computation time.
Returns an S4 object of type RLum.Results.
@data
$ De.value (data.frame)
.. $ De
.. $ De.error
.. $ Eta
$ De.MC (list) contains the matrices from the error estimation.
$ uniroot (list) contains the uniroot outputs of the De estimations
@info
'$ call“ (call) the original function call
0.1.3
Kreutzer, S., 2026. calc_gSGC(): Calculate De value based on the gSGC by Li et al., 2015. Function version 0.1.3. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
Li, B., Roberts, R.G., Jacobs, Z., Li, S.-H., 2015. Potential of establishing a 'global standardised growth curve' (gSGC) for optical dating of quartz from sediments. Quaternary Geochronology 27, 94-104. doi:10.1016/j.quageo.2015.02.011
RLum.Results, get_RLum, uniroot
results <- calc_gSGC(data = data.frame(
LnTn = 2.361, LnTn.error = 0.087,
Lr1Tr1 = 2.744, Lr1Tr1.error = 0.091,
Dr1 = 34.4))
get_RLum(results, data.object = "De")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.