View source: R/convert_SG2MG.R
| convert_SG2MG | R Documentation |
Conversion of single-grain data to multiple-grain data by adding signals from grains belonging to one disc (unique pairs of position, set and run).
convert_SG2MG(object, write_file = FALSE, ...)
object |
Risoe.BINfileData, character (required): Risoe.BINfileData object or BIN/BINX-file name. |
write_file |
logical (with default):
whether the output should be written to a file (only considered if |
... |
further arguments passed down to read_BIN2R and
write_R2BIN if |
A Risoe.BINfileData object. If write_file = TRUE an
the input was a file path, a file is also written out to origin folder.
0.1.1
Kreutzer, S., Mercier, N., 2026. convert_SG2MG(): Converts Single-Grain Data to Multiple-Grain Data. Function version 0.1.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Norbert Mercier, IRAMAT-CRP2A, UMR 5060, CNRS-Université Bordeaux Montaigne (France)
, RLum Developer Team
Risoe.BINfileData, read_BIN2R, write_R2BIN
## simple run
## (please not that the example is not using SG data)
data(ExampleData.BINfileData, envir = environment())
convert_SG2MG(CWOSL.SAR.Data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.