| import_Data | R Documentation |
Convenience wrapper function to provide a quicker and more standardised way of
reading data into R by looping through all in the package available data import
functions starting with read_. Import data types can be mixed.
import_Data(file, ..., fastForward = TRUE, verbose = FALSE)
file |
character (required): file to be imported, can be a list or a character vector |
... |
arguments to be further passed down to supported functions (please check the functions to determine the correct arguments) |
fastForward |
logical (with default): option to create RLum objects during import or a list of such objects |
verbose |
logical (with default): enable/disable output to the terminal. |
Always returns a list; empty or filled with RLum.Analysis objects
0.1.6
Kreutzer, S., 2026. import_Data(): Import Luminescence Data into R. Function version 0.1.6. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
read_BIN2R, read_BINXLOG2R, read_Daybreak2R, read_HeliosOSL2R, read_PSL2R, read_RF2R, read_SPE2R, read_TIFF2R, read_XSYG2R
## import BINX/BIN
file <- system.file("extdata/BINfile_V8.binx", package = "Luminescence")
temp <- import_Data(file)
## RF data
file <- system.file("extdata", "RF_file.rf", package = "Luminescence")
temp <- import_Data(file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.