| length_RLum | R Documentation |
The function provides a generalised access point for specific RLum objects. Depending on the input object, the corresponding function will be selected.
length_RLum(object)
## S4 method for signature 'RLum.Analysis'
length_RLum(object)
## S4 method for signature 'RLum.Data.Curve'
length_RLum(object)
## S4 method for signature 'RLum.Results'
length_RLum(object)
object |
RLum (required):
S4 object of class |
An integer indicating the length of the object.
length_RLum(RLum.Analysis): Returns the number of records stored in the object.
length_RLum(RLum.Data.Curve): Returns the length of the curve object, which is the maximum of the value
time/temperature of the curve (corresponding to the stimulation length).
length_RLum(RLum.Results): Returns the number of stored data elements.
0.1.0
Kreutzer, S., 2026. length_RLum(): Length retrieval function for RLum-class objects. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum.Data.Curve, RLum.Data.Image, RLum.Data.Spectrum, RLum.Analysis, RLum.Results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.