melt_RLum: Melt RLum-class objects into a flat data.frame

melt_RLumR Documentation

Melt RLum-class objects into a flat data.frame

Description

Melt RLum-class objects into a flat data.frame

Usage

melt_RLum(object, ...)

## S4 method for signature 'list'
melt_RLum(object, ...)

## S4 method for signature 'RLum.Analysis'
melt_RLum(object)

## S4 method for signature 'RLum.Data.Curve'
melt_RLum(object)

Arguments

object

RLum (required): S4 object of class RLum

...

further arguments passed to the specific class method

Value

A flat data.frame.

Methods (by class)

  • melt_RLum(list): Returns a list of melted RLum objects; non-RLum objects are silently removed.

  • melt_RLum(RLum.Analysis): Melts RLum.Analysis objects into a flat data.frame with columns X, Y, TYPE, UID, to be used in combination with other packages such as ggplot2.

  • melt_RLum(RLum.Data.Curve): Melts RLum.Data.Curve objects into a flat data.frame with columns X, Y, TYPE, UID, to be used in combination with other packages such as ggplot2.

Function version

0.1.0

How to cite

Kreutzer, S., 2026. melt_RLum(): Melt RLum-class objects into a flat data.frame. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/

Author(s)

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

See Also

RLum.Data.Curve, RLum.Analysis

Examples

data(ExampleData.XSYG, envir = environment())
melt_RLum(OSL.SARMeasurement[[2]][[1]])


Luminescence documentation built on Sept. 18, 2026, 9:07 a.m.