merge_RLum.Analysis: Merge function for RLum.Analysis S4 class objects

View source: R/merge_RLum.Analysis.R

merge_RLum.AnalysisR Documentation

Merge function for RLum.Analysis S4 class objects

Description

This function simply allows to merge RLum.Analysis objects. Moreover, other RLum.Data objects can be added to an existing RLum.Analysis object. Supported objects to be added are: RLum.Data.Curve, RLum.Data.Spectrum and RLum.Data.Image.

Usage

merge_RLum.Analysis(object, ...)

Arguments

object

list of RLum.Analysis (required): list of S4 objects of class RLum.Analysis. Furthermore other objects of class RLum can be added, see details.

...

currently not used.

Value

Returns an RLum.Analysis object ordered according to the order provided with the input list.

Function version

0.2.4

How to cite

Kreutzer, S., 2026. merge_RLum.Analysis(): Merge function for RLum.Analysis S4 class objects. Function version 0.2.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/

Note

The information for the slot 'protocol' is taken from the first RLum.Analysis object in the input list. Therefore at least one object of type RLum.Analysis has to be provided.

Author(s)

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

See Also

merge_RLum, RLum.Analysis, RLum.Data.Curve, RLum.Data.Spectrum, RLum.Data.Image, RLum

Examples


##merge different RLum objects from the example data
data(ExampleData.RLum.Analysis, envir = environment())
data(ExampleData.BINfileData, envir = environment())

object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)
curve <- get_RLum(object)[[2]]

temp.merged <- merge_RLum.Analysis(list(curve, IRSAR.RF.Data, IRSAR.RF.Data))


Luminescence documentation built on Sept. 18, 2026, 9:07 a.m.