| plot_DetPlot | R Documentation |
Plots the equivalent dose (D_e) in dependency of the chosen signal integral
(cf. Bailey et al., 2003). The function is simply passing several arguments
to the function plot and the used analysis functions and runs it in a loop.
Example: legend.pos for legend position, legend for legend text.
plot_DetPlot(
object,
signal_integral,
background_integral,
method = "shift",
signal_integral.seq = NULL,
integral_input = c("channel", "measurement"),
analyse_function = c("analyse_SAR.CWOSL", "analyse_pIRIRSequence"),
analyse_function.control = list(),
n.channels = NULL,
show_ShineDownCurve = TRUE,
respect_RC.Status = FALSE,
cores = NULL,
verbose = TRUE,
plot = TRUE,
...
)
object |
RLum.Analysis (required): input object containing data for analysis. Can be provided as a list of such objects. |
signal_integral |
integer (required): vector of channels for the signal integral. |
background_integral |
integer (required): vector of channels for the background integral. |
method |
character (with default): method applied for constructing the De(t) plot.
|
signal_integral.seq |
numeric (optional): argument to provide an own signal integral sequence for constructing the De(t) plot |
integral_input |
character (with default):
input type for |
analyse_function |
character (with default): name of the analyse function to be called. Supported functions are: analyse_SAR.CWOSL, analyse_pIRIRSequence |
analyse_function.control |
list (optional):
selected arguments to be passed to the supported analyse functions
(analyse_SAR.CWOSL, analyse_pIRIRSequence).
The arguments must be provided as named list, e.g.,
|
n.channels |
integer (optional): number of channels used for the De(t) plot. If nothing is provided all De-values are calculated and plotted until the start of the background integral. |
show_ShineDownCurve |
logical (with default): enable/disable shine down curve in the plot output. |
respect_RC.Status |
logical (with default): remove De values with 'FAILED' RC.Status from the plot (cf. analyse_SAR.CWOSL and analyse_pIRIRSequence). |
cores |
integer, numeric (with default):
number of cores allocated for parallel processing when |
verbose |
logical (with default): enable/disable output to the terminal. |
plot |
logical (with default): enable/disable the plot output. Disabling the plot is useful in cases where the output need to be processed differently. |
... |
further arguments and graphical parameters passed to
plot.default, analyse_SAR.CWOSL and analyse_pIRIRSequence (see details for further information).
Plot control parameters are: |
The original method presented by Bailey et al. (2003) shifts the signal
integrals and slightly extends them to account for changes in counting
statistics, producing sequences such as c(1:3, 3:5, 5:7).
Here we provide an additional method that expands the signal integral
consecutively by its chosen length, producing sequences like
c(1:3, 1:5, 1:7) instead.
Note that in both cases the integral limits overlap. The finally applied limits are part of the function output.
analyse_function.control
The argument analyse_function.control currently supports the following arguments:
sequence.structure, dose.points, dose_rate_source, mtext.outer,
fit.method, fit.force_through_origin, trim_channels, plot and
plot_singlePanels.
A plot and an RLum.Results object with the produced D_e values
@data:
| Object | Type | Description |
De.values | data.frame | table with De values |
signal_integral.seq | numeric | integral sequence used for the calculation |
@info:
| Object | Type | Description |
| call | call | the original function call |
0.1.12
Kreutzer, S., 2026. plot_DetPlot(): Create De(t) plot. Function version 0.1.12. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
The entire analysis relies on the functions analyse_SAR.CWOSL and analyse_pIRIRSequence. However, the integrity checks here are less rigorous than in those functions: therefore, every sequence should be checked carefully before running long calculations over hundreds of channels.
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
Bailey, R.M., Singarayer, J.S., Ward, S., Stokes, S., 2003. Identification of partial resetting using De as a function of illumination time. Radiation Measurements 37, 511-518. doi:10.1016/S1350-4487(03)00063-5
plot, analyse_SAR.CWOSL, analyse_pIRIRSequence
## Not run:
##load data
##ExampleData.BINfileData contains two BINfileData objects
##CWOSL.SAR.Data and TL.SAR.Data
data(ExampleData.BINfileData, envir = environment())
##transform the values from the first position in a RLum.Analysis object
object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)
plot_DetPlot(
object,
signal_integral = 1:3,
background_integral = 900:1000,
n.channels = 5)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.