View source: R/plot_OSLAgeSummary.R
| plot_OSLAgeSummary | R Documentation |
The function produces a graphical summary of the statistical inference of an OSL age.
plot_OSLAgeSummary(object, level = 0.95, digits = 1L, verbose = TRUE, ...)
object |
RLum.Results, numeric (required): an object produced by combine_De_Dr. Alternatively, a numeric vector of a parameter from an MCMC process. |
level |
numeric (with default): probability of shown credible interval. |
digits |
integer (with default): number of digits considered for the calculation. |
verbose |
logical (with default): enable/disable output to the terminal. |
... |
further arguments to modify the plot, supported: |
The function is called automatically by combine_De_Dr.
A posterior distribution plot and an RLum.Results object with the credible interval.
0.1.0
Philippe, A., Galharret, J., Mercier, N., Kreutzer, S., 2026. plot_OSLAgeSummary(): Plot Posterior OSL-Age Summary. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Anne Philippe, Université de Nantes (France)
Jean-Michel Galharret, Université de Nantes (France)
Norbert Mercier, IRAMAT-CRP2A, Université Bordeaux Montaigne (France)
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
, RLum Developer Team
combine_De_Dr, plot.default, rjags::rjags
##generate random data
set.seed(1234)
object <- rnorm(1000, 100, 10)
plot_OSLAgeSummary(object)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.