View source: R/plot_RLum.Results.R
| plot_RLum.Results | R Documentation |
The function provides a standardised plot output for data of an RLum.Results
S4 class object, redirecting to specialised functions if necessary.
plot_RLum.Results(object, single = TRUE, ...)
object |
RLum.Results (required):
S4 object of class |
single |
logical (with default):
single plot output ( |
... |
further arguments and graphical parameters will be passed to
the |
The function may produce multiple plots, in which case a file output is recommended (e.g., pdf).
Returns multiple plots.
0.2.2
Burow, C., Kreutzer, S., 2026. plot_RLum.Results(): Plot function for an RLum.Results S4 class object. Function version 0.2.2. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Not all arguments available for plot will be passed!
Only plotting of RLum.Results objects are supported.
Christoph Burow, University of Cologne (Germany)
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
, RLum Developer Team
plot, plot_RLum
###load data
data(ExampleData.DeValues, envir = environment())
# apply the un-logged minimum age model
mam <- calc_MinDose(data = ExampleData.DeValues$CA1, sigmab = 0.2, log = TRUE, plot = FALSE)
##plot
plot_RLum.Results(mam)
# estimate the number of grains on an aliquot
grains<- calc_AliquotSize(grain.size = c(100,150), sample.diameter = 1, plot = FALSE, MC.iter = 100)
##plot
plot_RLum.Results(grains)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.