Learn R Programming

Luminescence (version 0.1.7)

readBIN2R: Import Risoe BIN-file into R

Description

Import a *.bin file produced by a Risoe DA15 and DA20 TL/OSL reader into R.

Usage

readBIN2R(file)

Arguments

file
character (required): the bin-file name (including path), e.g. [WIN]: readBIN2R("C:/Desktop/test.bin"), [MAC/LINUX]: readBIN2R("/User/test/Desktop/test.bin")

Value

  • Return a S4 Risoe.BINfileData-class object containing two slots:
  • METADATAA data.frame containing all variables stored in the bin-file.
  • DATAA list containing a numeric vector of the measured data. The ID corresponds to the record ID in METADATA

Details

The binary data file is parsed byte per byte following the data structure published in the Appendices of the Analyst manual p. 42.

References

Duller, G. (2007). Analyst.

See Also

readBin

Examples

Run this code
##

Run the code above in your browser using DataLab