remove_RLum: Strips records from RLum-class objects

remove_RLumR Documentation

Strips records from RLum-class objects

Description

Remove records from an RLum-class object in a convenient way using get_RLum for the selection.

Usage

remove_RLum(object, ...)

## S4 method for signature 'list'
remove_RLum(object, ...)

## S4 method for signature 'RLum.Analysis'
remove_RLum(object, ...)

Arguments

object

RLum (required): object with records to be removed.

...

parameters to be passed to get_RLum. Only the following named arguments are supported: record.id, recordType, curveType, RLum.type, protocol, info.object and subset. Arguments get.index and drop are preset to TRUE and FALSE, respectively, and cannot be overridden. Other named arguments are ignored, while unnamed arguments are not supported.

Value

An object of the same type as the input provided with records removed; it can result in an empty object.

Methods (by class)

  • remove_RLum(list): Returns a list of RLum objects where the selected records are stripped

  • remove_RLum(RLum.Analysis): Method to remove records from an RLum.Analysis object.

Function version

0.1.0

How to cite

Kreutzer, S., 2026. remove_RLum(): Strips records from RLum-class objects. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/

Author(s)

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

See Also

RLum.Analysis

Examples

## load example data
data(ExampleData.XSYG, envir = environment())
sar <- OSL.SARMeasurement$Sequence.Object[1:9]

## strop only OSL curves
sar <- remove_RLum(sar, recordType = "OSL")
sar


Luminescence documentation built on Sept. 18, 2026, 9:07 a.m.