View source: R/scale_GammaDose.R
| scale_GammaDose | R Documentation |
This function calculates the gamma dose deposited in a luminescence sample taking into account layer-to-layer variations in sediment radioactivity according to Aitken, 1985. The function scales user inputs of uranium, thorium and potassium based on input parameters for sediment density, water content and given layer thicknesses and distances to the sample.
User Input
To calculate the gamma dose deposited in a sample, the user needs to provide sediment information that may influence the luminescence sample. As a rule of thumb, all sediment layers within at least a 30 cm radius from the luminescence sample should be taken into account when calculating the gamma dose rate. However, the actual range of gamma radiation might be different, depending on the emitting radioelements, the water content and the sediment density of each layer (Aitken, 1985). Therefore, the user is advised to provide as much detail as possible that is physically sensible.
The function requires a data.frame with the samples listed in rows. In order, the columns should contain:
Column 1 contains information on the layer/sample ID.
Column 2 gives the thickness (in cm) of each layer.
Column 3: for the layer from which the OSL/TL sample was taken, the
distance (in cm) measured from the middle of the sample to the bottom
of the layer of interest must be provided. If the whole layer was sampled,
insert 0. All layers that are not sampled for OSL/TL should be set to NA.
Columns 4 to 9 contain radionuclide concentrations and their standard errors for potassium (in %), thorium (in ppm) and uranium (in ppm).
Columns 10 and 11 give information on the water content and its standard error in %.
Column 12 contains the layer density (in g/cm³).
No cell should be left blank. Please ensure that the column names match
those given in the example dataset, see data('ExampleData.ScaleGammaDose').
The user can decide which dose rate conversion factors should be used to calculate the gamma dose rates. The options are:
"Cresswelletal2018" (Cresswell et al., 2018)
"Liritzisetal2013" (Liritzis et al., 2013)
"Guerinetal2011" (Guérin et al., 2011)
"AdamiecAitken1998" (Adamiec and Aitken, 1998)
Water content
The water content provided by the user should be calculated according to:
\frac{\mathrm{Wet\ weight [g]} - \mathrm{Dry\ weight [g]}}
{\mathrm{Dry\ weight [g]}} * 100
Calculations
After converting the radionuclide concentrations into dose rates, the function will scale the dose rates based on the thickness of the layers, the distances to the sample, the water content and the density of the sediment. The calculations are based on Aitken (1985, Appendix H). As an example (equivalent to Aitken, 1985), assuming three layers of sediment, where L is inert and positioned in between the infinite thick and equally active layers A and B, the dose in L and B due to A is given by
{1-f(x)}D_A
Where x is the distance into the inert medium, so f(x) is the weighted
average fractional dose at x and D_A denotes that the dose is delivered by A.
f(x) is derived from table H1 (Aitken, 1985), when setting z = x.
Consequently, the dose in A and L due to B is given by
{1 - f(t-x)}D_B
Here t is the thickness of L and the other parameters are denoted as above,
just for the dose being delivered by B. f(t-x) is derived from table H1
(Aitken, 1985), when setting z equal to t-x. Following this, the dose in L
delivered by A and B is given by
{2 - f(x) - f(t-x)}D_{AB}
Since A and B are equally active D_{AB} = D_A = D_B.
The function uses the value of the fractional dose rate at the layer boundary to start the calculation for the next layer. This way, the function is able to scale the gamma dose rate accurately for distant layers when the density and water content is not constant for the entire section.
scale_GammaDose(
data,
conversion_factors = c("Cresswelletal2018", "Guerinetal2011", "AdamiecAitken1998",
"Liritzisetal2013"),
fractional_gamma_dose = "Aitken1985",
verbose = TRUE,
plot = TRUE,
plot_singlePanels = FALSE,
...
)
data |
data.frame (required): A table containing all relevant information for each individual layer. The table must have the following named columns:
|
conversion_factors |
character (optional): The conversion factors used to calculate the dose rate from sediment nuclide contents. Valid options are:
|
fractional_gamma_dose |
character (optional): Factors to scale gamma dose rate values. Valid options are:
|
verbose |
logical (with default): enable/disable output to the terminal. |
plot |
logical (with default): enable/disable the plot output. |
plot_singlePanels |
logical (with default): enable/disable single plot mode, i.e. one plot window per plot. |
... |
Further parameters passed to barplot. |
After performing the calculations the user is provided with different outputs.
The total gamma dose rate received by the sample (+/- uncertainties) as a print in the console.
A plot showing the sediment sequence, the user input sample information and the contribution to total gamma dose rate.
RLum Results. If the user wishes to save these results, writing a script to run the function and to save the results would look like this:
mydata <- read.table("c:/path/to/input/file.txt")
results <- scale_GammaDose(mydata)
table <- get_RLum(results)
write.csv(table, "c:/path/to/results.csv")
———————————–
[ NUMERICAL OUTPUT ]
———————————–
RLum.Results-object
slot: @data
| Element | Type | Description |
$summary | data.frame | summary of the model results |
$data | data.frame | the original input data |
$dose_rates | list | two data.frames for the scaled and infinite matrix dose rates |
$tables | list | several data.frames containing intermediate results |
$args | character | arguments of the call |
$call | call | the original function call |
slot: @info
Currently unused.
————————
[ PLOT OUTPUT ]
————————
Three plots are produced:
A visualisation of the provided sediment layer structure to quickly assess whether the data was provided and interpreted correctly.
A scatter plot of the nuclide contents per layer (K, Th, U) as well as the water content. This may help to correlate the dose rate contribution of specific layers to the layer of interest.
A barplot visualising the contribution of each layer to the total dose rate received by the sample in the target layer.
0.1.4
We thank Dr Ian Bailiff for the provision of an excel spreadsheet, which has been very helpful when writing this function.
Riedesel, S., Autzen, M., Burow, C., 2026. scale_GammaDose(): Calculate the gamma dose deposited within a sample accounting for layer-to-layer variations in radioactivity. Function version 0.1.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
This function has BETA status. If possible, results should be cross-checked.
Svenja Riedesel, Aberystwyth University (United Kingdom)
Martin Autzen, DTU NUTECH Center for Nuclear Technologies (Denmark)
Christoph Burow, University of Cologne (Germany)
Based on an excel spreadsheet and accompanying macro written by Ian Bailiff.
, RLum Developer Team
Aitken, M.J., 1985. Thermoluminescence Dating. Academic Press, London.
Adamiec, G., Aitken, M.J., 1998. Dose-rate conversion factors: update. Ancient TL 16, 37-46. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.26034/la.atl.1998.292")}
Cresswell., A.J., Carter, J., Sanderson, D.C.W., 2018. Dose rate conversion parameters: Assessment of nuclear data. Radiation Measurements 120, 195-201. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.radmeas.2018.02.007")}
Guérin, G., Mercier, N., Adamiec, G., 2011. Dose-rate conversion factors: update. Ancient TL 29, 5-8. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.26034/la.atl.2011.443")}
Liritzis, I., Stamoulis, K., Papachristodoulou, C., Ioannides, K., 2013. A re-evaluation of radiation dose-rate conversion factors. Mediterranean Archaeology and Archaeometry 13, 1-15.
ExampleData.ScaleGammaDose, BaseDataSet.ConversionFactors, approx, barplot
# Load example data
data("ExampleData.ScaleGammaDose", envir = environment())
# Scale gamma dose rate
results <- scale_GammaDose(data = ExampleData.ScaleGammaDose,
conversion_factors = "Cresswelletal2018",
fractional_gamma_dose = "Aitken1985",
verbose = TRUE,
plot = TRUE)
get_RLum(results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.