| smooth_RLum | R Documentation |
The function provides a generalised access point for specific
RLum objects. Depending on the input object, the corresponding
function will be selected. The smoothing is performed in the internal
function .smoothing().
smooth_RLum(object, ...)
## S4 method for signature 'list'
smooth_RLum(object, ...)
## S4 method for signature 'RLum.Analysis'
smooth_RLum(object, ...)
## S4 method for signature 'RLum.Data.Curve'
smooth_RLum(
object,
k = NULL,
fill = NA,
align = "right",
method = "mean",
p_acceptance = 1e-07
)
object |
RLum (required):
S4 object of class |
... |
further arguments passed to the specific class method |
k |
smooth_RLum; integer (with default):
window for the rolling mean or median. If |
fill |
smooth_RLum; numeric (with default): value used to pad the result so to have the same length as the input. |
align |
smooth_RLum; character (with default):
one of |
method |
smooth_RLum; character (with default):
smoothing method to be applied: one of |
p_acceptance |
smooth_RLum; numeric (with default):
probability threshold of accepting a value to be a sample from a Poisson
distribution (only used for |
An object of the same type as the input object provided.
smooth_RLum(list): Returns a list of RLum objects that had been passed to
smooth_RLum
smooth_RLum(RLum.Analysis): Smoothing of RLum.Data records contained in the input object.
smooth_RLum(RLum.Data.Curve): Smoothing of RLum.Data.Curve objects using a rolling mean or median.
For methods "mean" and "median", smoothing is performed by rolling
mean and rolling median with window of size k. Method "Carter_etal_2018"
implements a Poisson smoother for dark-background signals measured by a
photomultiplier tube.
0.1.0
Kreutzer, S., 2026. smooth_RLum(): Smoothing of data for RLum-class objects. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Currently only RLum objects of class RLum.Data.Curve and RLum.Analysis
(with curve data) are supported.
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
Carter, J., Cresswell, A.J., Kinnaird, T.C., Carmichael, L.A., Murphy, S. & Sanderson, D.C.W., 2018. Non-Poisson variations in photomultipliers and implications for luminescence dating. Radiation Measurements 120, 267-273. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.radmeas.2018.05.010")}
RLum.Data.Curve, RLum.Analysis
## load example data
data(ExampleData.CW_OSL_Curve, envir = environment())
## create RLum.Data.Curve object from this example
curve <-
set_RLum(
class = "RLum.Data.Curve",
recordType = "OSL",
data = as.matrix(ExampleData.CW_OSL_Curve)
)
## plot data without and with smoothing
plot_RLum(curve)
plot_RLum(smooth_RLum(curve))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.