| sort_RLum | R Documentation |
The function provides a generalised access point for specific RLum and Risoe.BINfileData objects. Depending on the input object, the corresponding function will be selected.
sort_RLum(object, ...)
## S4 method for signature 'list'
sort_RLum(object, ...)
## S4 method for signature 'RLum.Analysis'
sort_RLum(object, slot = NULL, info_element = NULL, decreasing = FALSE, ...)
## S4 method for signature 'Risoe.BINfileData'
sort_RLum(object, info_element, decreasing = FALSE, ...)
object |
RLum or
Risoe.BINfileData (required):
S4 object of class |
... |
further arguments passed to the specific class method |
slot |
character (optional): slot name to use in sorting. |
info_element |
character (optional): names of the |
decreasing |
logical (with default): whether the sort order should
be decreasing ( |
An object of the same type as the input object provided.
sort_RLum(list): Returns a list of sorted RLum objects.
sort_RLum(RLum.Analysis): Sorting of RLum.Data objects contained in this RLum.Analysis object.
At least one of slot and info_element must be provided. If both are
given, ordering by slot always takes priority over info_element.
Only the first element in each slot and each info_element is used
for sorting. Example: .pid can contain multiple values, however, only the
first is taken.
Please note that the show() method does some structuring, which may
lead to the impression that the sorting did not work.
sort_RLum(Risoe.BINfileData): Sort method for Risoe.BINfileData objects.
0.1.0
Colombo, M., 2026. sort_RLum(): Sort data for RLum-class and Risoe.BINfileData-class objects. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Marco Colombo, Institute of Geography, Heidelberg University (Germany) , RLum Developer Team
RLum.Analysis, Risoe.BINfileData
## load example data
data(ExampleData.XSYG, envir = environment())
obj <- OSL.SARMeasurement$Sequence.Object[1:9]
sort_RLum(obj, slot = "recordType")
sort_RLum(obj, info_element = "curveDescripter")
data(ExampleData.XSYG, envir = environment())
sar <- OSL.SARMeasurement$Sequence.Object[1:5]
sort_RLum(sar, solt = "recordType", info_element = c("startDate"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.