structure_RLum: General structure function for RLum-class objects

structure_RLumR Documentation

General structure function for RLum-class objects

Description

The function provides a generalised access point for specific RLum objects. Depending on the input object, the corresponding function will be selected.

Usage

structure_RLum(object, ...)

## S4 method for signature 'list'
structure_RLum(object, ...)

## S4 method for signature 'RLum.Analysis'
structure_RLum(object, fullExtent = FALSE)

Arguments

object

RLum (required): S4 object of class RLum

...

further arguments passed to the specific class method

fullExtent

logical (with default): extends the returned data.frame to its full extent, i.e. all info elements are part of the return as well. The default value is FALSE as the data frame might become rather big.

Value

Returns a data.frame with structure of the object.

Methods (by class)

  • structure_RLum(list): Returns a list of data frames containing the structure of each RLum object in the input list.

  • structure_RLum(RLum.Analysis): Returns the structure of an RLum.Analysis object.

Function version

0.2.0

How to cite

Kreutzer, S., 2026. structure_RLum(): General structure function for RLum-class objects. Function version 0.2.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/

Author(s)

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

See Also

RLum.Data.Curve, RLum.Data.Image, RLum.Data.Spectrum, RLum.Analysis, RLum.Results

Examples


## load example data
data(ExampleData.XSYG, envir = environment())

## show structure
structure_RLum(OSL.SARMeasurement$Sequence.Object)


Luminescence documentation built on Sept. 18, 2026, 9:07 a.m.