View source: R/subset_SingleGrainData.R
| subset_SingleGrainData | R Documentation |
Most measured single grains do not exhibit light and it usually makes sense to subset single grain datasets using a table of position and grain pairs.
subset_SingleGrainData(object, selection)
object |
Risoe.BINfileData (required): input object with the data to subset. |
selection |
data.frame, matrix (required): selection table with two columns for position and grain, respectively. |
A subset Risoe.BINfileData object
0.1.1
Kreutzer, S., 2026. subset_SingleGrainData(): Simple Subsetting of Single Grain Data from Risø BIN/BINX files. Function version 0.1.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
Risoe.BINfileData, read_BIN2R, verify_SingleGrainData
## load example data
data(ExampleData.BINfileData, envir = environment())
## set POSITION/GRAIN pair dataset
selection <- data.frame(POSITION = c(1,5,7), GRAIN = c(0,0,0))
##subset
subset_SingleGrainData(object = CWOSL.SAR.Data, selection = selection)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.