| write_R2TIFF | R Documentation |
Simple wrapper around tiff::writeTIFF to export suitable RLum objects to TIFF images. Per default 16-bit TIFF files are exported.
write_R2TIFF(object, file = tempfile(), norm = 65535, ...)
object |
RLum.Data.Image or RLum.Data.Spectrum object (required): input object, can be a list of such objects. |
file |
character (required): name of the output file. |
norm |
numeric (with default):
normalisation value. Usually, in imaging applications the pixel values are
integer count values, but values in TIFF files must be in the 0-1 range.
Normalising to the to the highest 16-bit integer values - 1 ensures that
the numerical values are retained in the exported image. If |
... |
further arguments to be passed to tiff::writeTIFF. |
A TIFF file
0.1.2
Kreutzer, S., 2026. write_R2TIFF(): Export RLum.Data.Image and RLum.Data.Spectrum objects to TIFF Images. Function version 0.1.2. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
tiff::writeTIFF, RLum.Data.Image, RLum.Data.Spectrum
data(ExampleData.RLum.Data.Image, envir = environment())
write_R2TIFF(ExampleData.RLum.Data.Image, file = tempfile(fileext = ".tiff"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.