data.frame (required): requires an OSL shine down curve (x=time,y=counts)
Tx.data
data.frame (optional): requires an OSL shine down curve (x=time,y=counts). If no input is given the Tx.data will
be treated as NA and no Lx/Tx ratio is calculated.
signal.integral
vector (required): requires a vector with the bounds for the signal integral.
background.integral
vector (required): requires a vector with the bounds for the background integral.
The integrity of the chosen values for the signal and background integral are checked by the function.
If a vector is given as input instead of a data.frame an artifical data.frame
is produced.
The error calculation is done according Galbraith (2002).
References
Duller, G., 2007. Analyst.
Galbraith, R.F., 2002. A note on the variance of a background-corrected OSL count. Ancient TL, 20 (2), 49-51.