Description
Abstract class for data in the package Luminescence
Usage
"replicate_RLum"(object, times = NULL)
Arguments
object
an object of class RLum (required)
times
integer (optional): number for times each element is repeated
elementMethods (by generic)
-
replicate_RLum: Replication method RLum-objects
Slots
originator- Object of class
character containing the name of the producing
function for the object. Set automatically by using the function set_RLum. info- Object of class
list for additional information on the object itself .uid- Object of class
character for a unique object identifier. This id is
usually calculated using the internal function .create_UID() if the funtion set_RLum
is called. .pid- Object of class
character for a parent id. This allows nesting RLum-objects
at will. The parent id can be the uid of another object.
Objects from the Class
A virtual Class: No objects can be created
from it.Class version
0.4.0See Also
RLum.Data, RLum.Analysis