| RLum.Data.Image-class | R Documentation |
"RLum.Data.Image"Class for representing luminescence image data (TL/OSL/RF). Such data are for example produced by function read_SPE2R.
recordTypeObject of class character containing the type of the curve (e.g. "OSL image", "TL image").
curveTypeObject of class character containing curve type, allowed values are measured or predefined
dataObject of class array containing image data.
infoObject of class list containing further meta information objects
Objects can be created by calls of the form set_RLum("RLum.Data.Image", ...).
0.5.1
The class should only contain data for a set of images. For additional
elements the slot info can be used.
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum, RLum.Data, plot_RLum, read_SPE2R, read_TIFF2R
showClass("RLum.Data.Image")
##create empty RLum.Data.Image object
set_RLum(class = "RLum.Data.Image")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.