| RLum.Data.Spectrum-class | R Documentation |
"RLum.Data.Spectrum"Class for representing luminescence spectra data (TL/OSL/RF).
recordTypeObject of class character containing the type of the curve (e.g. "TL" or "OSL")
curveTypeObject of class character containing curve type, allowed values are "measured" or "predefined"
dataObject of class matrix containing spectrum (count) values. Row labels indicate wavelength/pixel values, column labels are temperature or time values.
infoObject of class list containing further meta information objects
Objects can be created by calls of the form set_RLum("RLum.Data.Spectrum", ...).
0.5.2
The class should only contain data for a single spectra data set. For
additional elements the slot info can be used. Objects from this class are automatically
created by, e.g., read_XSYG2R
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum, RLum.Data, plot_RLum
showClass("RLum.Data.Spectrum")
##show example data
data(ExampleData.XSYG, envir = environment())
TL.Spectrum
##show data matrix
get_RLum(TL.Spectrum)
##plot spectrum
## Not run:
plot_RLum(TL.Spectrum)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.