"Risoe.BINfileData"read_BIN2R.
"show"(object)
"set_Risoe.BINfileData"(METADATA, DATA, .RESERVED)
"get_Risoe.BINfileData"(object, ...)Risoe.BINfileDatashow: Show structure of RLum and Risoe.BINfile class objects set_Risoe.BINfileData: The Risoe.BINfileData is normally produced as output of the function read_BIN2R.
This construction method is intended for internal usage only. get_Risoe.BINfileData: Formal get-method for Risoe.BINfileData object. It does not allow accessing
the object directly, it is just showing a terminal message.
METADATADATA.RESERVEDnew("Risoe.BINfileData", ...).http://www.nutech.dtu.dk/
plot_Risoe.BINfileData, read_BIN2R,
write_R2BIN,merge_Risoe.BINfileData,
Risoe.BINfileData2RLum.Analysis,
showClass("Risoe.BINfileData")
Run the code above in your browser using DataLab