The function performs a SAR TL analysis on a RLum.Analysis object including growth curve fitting.
analyse_SAR.TL(
object,
object.background,
signal_integral,
integral_input = "channel",
sequence.structure = c("PREHEAT", "SIGNAL", "BACKGROUND"),
rejection.criteria = list(recycling.ratio = 10, recuperation.rate = 10),
dose.points = NULL,
log = "",
...
)A plot (optional) and an RLum.Results object is returned containing the following elements:
data.frame containing De-values and further parameters
data.frame of all calculated Lx/Tx values including signal, background counts and the dose points.
data.frame with values that might by used as rejection criteria. NA is produced if no R0 dose point exists.
The output should be accessed using the function get_RLum.
RLum.Analysis or a list of such objects (required) : input object containing data for analysis
currently not used
integer (required):
vector of inputs (as defined by integral_input) for the signal integral.
character (with default):
input type for signal_integral, one of "channel" (default) or
"measurement". If set to "measurement", the best matching channels
corresponding to the given temperature range are selected.
vector character (with default):
specifies the general sequence structure. Three steps are allowed
("PREHEAT", "SIGNAL", "BACKGROUND"), in addition a
parameter "EXCLUDE". This allows excluding TL curves which are not
relevant for the protocol analysis. (Note: No TL are removed by default)
list (with default): list containing rejection criteria in percentage for the calculation.
numeric (optional): option set dose points manually
character (with default):
a character string which contains "x" if the x-axis is to be logarithmic,
"y" if the y axis is to be logarithmic and "xy" or "yx" if both axes
are to be logarithmic. See
plot.default).
further arguments that will be passed to the function fit_DoseResponseCurve
0.3.4
Kreutzer, S., 2026. analyse_SAR.TL(): Analyse SAR TL measurements. Function version 0.3.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
This function performs a SAR TL analysis on a set of curves. The SAR
procedure in general is given by Murray and Wintle (2000). For the
calculation of the Lx/Tx value the function calc_TLLxTxRatio is
used.
Provided rejection criteria
[recycling.ratio]: calculated for every repeated regeneration dose point.
[recuperation.rate]: recuperation rate calculated by
comparing the Lx/Tx values of the zero regeneration point with the Ln/Tn
value (the Lx/Tx ratio of the natural signal). For methodological
background see Aitken and Smith (1988)
Aitken, M.J. and Smith, B.W., 1988. Optical dating: recuperation after bleaching. Quaternary Science Reviews 7, 387-393.
Murray, A.S. and Wintle, A.G., 2000. Luminescence dating of quartz using an improved single-aliquot regenerative-dose protocol. Radiation Measurements 32, 57-73.
calc_TLLxTxRatio, fit_DoseResponseCurve, RLum.Analysis, RLum.Results, get_RLum
##load data
data(ExampleData.BINfileData, envir = environment())
##transform the values from the first position in a RLum.Analysis object
object <- Risoe.BINfileData2RLum.Analysis(TL.SAR.Data, pos=3)
##perform analysis
analyse_SAR.TL(
object = object,
signal_integral = 210:220,
fit.method = "SSE OR LIN",
sequence.structure = c("SIGNAL", "BACKGROUND"))
Run the code above in your browser using DataLab