Skip to contents

The function applies spectral efficiency correction to RLum.Data.Spectrum objects.

Usage

apply_EfficiencyCorrection(object, spectral.efficiency)

Arguments

object

RLum.Data.Spectrum or RLum.Analysis (required): object of class RLum.Data.Spectrum, RLum.Analysisor a list of such objects. Other objects in the list are skipped.

spectral.efficiency

data.frame or character (required): either a data frame with 2 columns containing wavelengths and relative spectral response values (values between 0 and 1); or a character string specifying the path to a CSV file (with a header row), which the function will attempt to import via utils::read.csv. When object is a list, the provided data will be used to correct all spectra.

Value

Returns same object as provided as input

Details

The efficiency correction is based on a spectral response dataset provided by the user. Usually the data set for the quantum efficiency is of lower resolution and values are interpolated for the required spectral resolution using function stats::approx.

If the energy calibration differs for both data set NA values are produces that will be removed from the matrix.

Note

Please note that the spectral efficiency data from the camera alone may not sufficiently correct for spectral efficiency of the entire optical system (e.g., spectrometer, camera ...).

Function version

0.3.0

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Johannes Friedrich, University of Bayreuth (Germany) , RLum Developer Team

How to cite

Kreutzer, S., Friedrich, J., 2026. apply_EfficiencyCorrection(): Apply spectral efficiency correction to RLum.Data.Spectrum objects. Function version 0.3.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/

Examples


##(1) - use with your own data (uncomment for usage)
## spectral.efficiency <- read.csv("your data")
##
## your.spectrum <- apply_EfficiencyCorrection(your.spectrum, )