calc_FastRatio(object, stimulation.power = 30.6, wavelength = 470, sigmaF = 2.6e-17, sigmaM = 4.28e-18, Ch_L1 = 1, Ch_L2 = NULL, Ch_L3 = NULL, x = 1, x2 = 0.1, dead.channels = c(0, 0), fitCW.sigma = FALSE, fitCW.curve = FALSE, plot = TRUE, ...)RLum.Analysis,
RLum.Data.Curve or data.frame
(required): x, y data of measured values (time and counts).numeric (with default): Stimulation power in mW/cm^2numeric (with default): Stimulation wavelength in nmnumeric (with default): Photoionisation cross-section (cm^2) of the
fast component. Default value after Durcan & Duller (2011).numeric (with default): Photoionisation cross-section (cm^2) of the
medium component. Default value after Durcan & Duller (2011).numeric (with default): An integer specifying the channel for L1.numeric (optional): An integer specifying the channel for L2.numeric (optional): A vector of length 2 with integer
values specifying the start and end channels for L3 (e.g., c(40, 50)).numeric (with default): % of signal remaining from the fast component.
Used to define the location of L2 and L3 (start).numeric (with default): % of signal remaining from the medium component.
Used to define the location of L3 (end).numeric (with default): Vector of length 2 in the form of
c(x, y). Channels that do not contain OSL data, i.e. at the start or end of
measurement.logical (optional): fit CW-OSL curve using fit_CWCurve
to calculate sigmaF and sigmaM (experimental).logical (optional): fit CW-OSL curve using fit_CWCurve
and derive the counts of L2 and L3 from the fitted OSL curve (experimental).logical (with default): plot output (TRUE/FALSE)verbose (logical). Further
arguments passed to fit_CWCurve.RLum.Results.
The slot data contains a list with the following elements:x and
x2 % respectively using eq. 3 to determine channels L2 and L3 (start
and end). The fast ratio is then calculated from: $(L1-L3)/(L2-L3)$.
Madsen, A.T., Duller, G.A.T., Donnelly, J.P., Roberts, H.M. & Wintle, A.G., 2009. A chronology of hurricane landfalls at Little Sippewissett Marsh, Massachusetts, USA, using optical dating. Geomorphology 109, 36-45.
Further reading
Steffen, D., Preusser, F. & Schlunegger, 2009. OSL quartz age underestimation due to unstable signal components. Quaternary Geochronology 4, 353-362.
fit_CWCurve, get_RLum, RLum.Analysis,
RLum.Results, RLum.Data.Curve
# load example CW-OSL curve
data("ExampleData.CW_OSL_Curve")
# calculate the fast ratio w/o further adjustments
res <- calc_FastRatio(ExampleData.CW_OSL_Curve)
# show the summary table
get_RLum(res)
Run the code above in your browser using DataLab