Learn R Programming

Luminescence (version 0.6.2)

calc_HomogeneityTest: Apply a simple homogeneity test after Galbraith (2003)

Description

A simple homogeneity test for De estimates

Usage

calc_HomogeneityTest(data, log = TRUE, ...)

Arguments

data
RLum.Results or data.frame (required): for data.frame: two columns with De (data[,1]) and De error (values[,2])
log
logical (with default): peform the homogeniety test with (un-)logged data
...
further arguments (for internal compatibility only).

Value

Returns a terminal output. In addition an RLum.Results object is returned containing the following element:The output should be accessed using the function get_RLum

Function version

0.2 (2016-05-02 09:36:06)

Details

For details see Galbraith (2003).

References

Galbraith, R.F., 2003. A simple homogeneity test for estimates of dose obtained using OSL. Ancient TL 21, 75-77.

See Also

pchisq

Examples

Run this code

## load example data
data(ExampleData.DeValues, envir = environment())

## apply the homogeneity test
calc_HomogeneityTest(ExampleData.DeValues$BT998)

Run the code above in your browser using DataLab