Learn R Programming

Luminescence (version 1.3.0)

calc_MaxDose: Apply the maximum age model to a given De distribution

Description

Function to fit the maximum age model to De data. This is a wrapper function that calls calc_MinDose and applies a similar approach as described in Olley et al. (2006).

Usage

calc_MaxDose(
  data,
  sigmab,
  log = TRUE,
  par = 3,
  bootstrap = FALSE,
  init.values = NULL,
  plot = TRUE,
  ...
)

Value

Please see calc_MinDose.

Arguments

data

RLum.Results or data.frame (required): for data.frame: two columns with (data[, 1]) and De error (data[, 2]).

sigmab

numeric (required): additional spread in De values, representing the expected overdispersion in the data should the sample be well-bleached (Cunningham & Wallinga 2012, p. 100). This value must be expressed as a ratio, e.g. 0.2 (for 20 %), independently of the log argument.

Note: Up to v1.2.1, it was required that the unlogged model specified sigmab in the same absolute units of the De values (seconds or Gray). This is no longer the case, and an error will be thrown if values of sigmab greater than 1 are assigned.

log

logical (with default): whether the logged minimum dose model should be fit to De data (TRUE by default).

par

numeric (with default): number of parameters in the minimum age model, either 3 (default) or 4.

bootstrap

logical (with default): apply the recycled bootstrap approach of Cunningham & Wallinga 2012. See details for default values and options to modify them.

init.values

numeric (optional): a named list with starting values for gamma, sigma, p0 and mu (e.g. list(gamma=100, sigma=1.5, p0=0.1, mu=100)). If no values are provided, reasonable values will be estimated from the data. Note: the initial values must always be given in the absolute units. If a logged model is applied (log = TRUE), the provided init.values are automatically log-transformed.

plot

logical (with default): enable/disable the plot output.

...

further arguments for bootstrapping (bs.M, bs.N, bs.h, sigmab.sd). See details for their usage.

Function version

0.3.2

How to cite

Burow, C., 2026. calc_MaxDose(): Apply the maximum age model to a given De distribution. Function version 0.3.2. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/

Author

Christoph Burow, University of Cologne (Germany)
Based on a rewritten S script of Rex Galbraith, 2010 , RLum Developer Team

Details

Data transformation

To estimate the maximum dose population and its standard error, the three parameter minimum age model of Galbraith et al. (1999) is adapted. The measured De values are transformed as follows:

  1. convert De values to natural logs

  2. multiply the logged data to create a mirror image of the De distribution

  3. shift De values along x-axis by the smallest x-value found to obtain only positive values

  4. combine in quadrature the measurement error associated with each De value with a relative error specified by sigmab

  5. apply the MAM to these data

When all calculations are done the results are then converted as follows

  1. subtract the x-offset

  2. multiply the natural logs by -1

  3. take the exponent to obtain the maximum dose estimate in Gy

Further documentation

Please see calc_MinDose.

References

Arnold, L.J., Roberts, R.G., Galbraith, R.F. & DeLong, S.B., 2009. A revised burial dose estimation procedure for optical dating of young and modern-age sediments. Quaternary Geochronology 4, 306-325.

Galbraith, R.F. & Laslett, G.M., 1993. Statistical models for mixed fission track ages. Nuclear Tracks Radiation Measurements 4, 459-470.

Galbraith, R.F., Roberts, R.G., Laslett, G.M., Yoshida, H. & Olley, J.M., 1999. Optical dating of single grains of quartz from Jinmium rock shelter, northern Australia. Part I: experimental design and statistical models. Archaeometry 41, 339-364.

Galbraith, R.F., 2005. Statistics for Fission Track Analysis, Chapman & Hall/CRC, Boca Raton.

Galbraith, R.F. & Roberts, R.G., 2012. Statistical aspects of equivalent dose and error calculation and display in OSL dating: An overview and some recommendations. Quaternary Geochronology 11, 1-27.

Olley, J.M., Roberts, R.G., Yoshida, H., Bowler, J.M., 2006. Single-grain optical dating of grave-infill associated with human burials at Lake Mungo, Australia. Quaternary Science Reviews 25, 2469-2474

Further reading

Arnold, L.J. & Roberts, R.G., 2009. Stochastic modelling of multi-grain equivalent dose (De) distributions: Implications for OSL dating of sediment mixtures. Quaternary Geochronology 4, 204-230.

Bailey, R.M. & Arnold, L.J., 2006. Statistical modelling of single grain quartz De distributions and an assessment of procedures for estimating burial dose. Quaternary Science Reviews 25, 2475-2502.

Cunningham, A.C. & Wallinga, J., 2012. Realizing the potential of fluvial archives using robust OSL chronologies. Quaternary Geochronology 12, 98-106.

Rodnight, H., Duller, G.A.T., Wintle, A.G. & Tooth, S., 2006. Assessing the reproducibility and accuracy of optical dating of fluvial deposits. Quaternary Geochronology 1, 109-120.

Rodnight, H., 2008. How many equivalent dose values are needed to obtain a reproducible distribution?. Ancient TL 26, 3-10.

See Also

calc_CentralDose, calc_CommonDose, calc_FiniteMixture, calc_FuchsLang2001, calc_MinDose

Examples

Run this code

## load example data
data(ExampleData.DeValues, envir = environment())

# apply the maximum dose model
calc_MaxDose(ExampleData.DeValues$CA1, sigmab = 0.2, par = 3)

Run the code above in your browser using DataLab