Learn R Programming

Luminescence (version 1.2.1)

calc_SourceDoseRate: Calculation of the source dose rate via the date of measurement

Description

Calculating the dose rate of the irradiation source via the date of measurement based on: source calibration date, source dose rate, dose rate error. The function returns a data.frame that provides the input argument dose_rate for the function convert_Second2Gray.

Calculation of the source dose rate based on the time elapsed since the last calibration of the irradiation source. Decay parameters assume a Sr-90 beta source. $$dose.rate = D0 \exp(-\frac{\log(2)}{T.1/2} t)$$

where D0 is the calibration dose rate, \(T.1/2\) is the half-life of the source nuclide (in days), t is the time since source calibration (in days), and \(\log(2) / T.1/2\) equals the decay constant lambda.

Information on the date of measurements may be taken from the data's original .BIN file (using e.g., BINfile <- Luminescence::read_BIN2R() and the slot BINfile@METADATA$DATE).

Allowed source types and related values

#Source typeT.1/2Reference
[1]Sr-9028.90 yNNDC, Brookhaven National Laboratory
[2]Am-214432.6 yNNDC, Brookhaven National Laboratory
[3]Co-605.274 yNNDC, Brookhaven National Laboratory
[4]Cs-13730.08 yNNDC, Brookhaven National Laboratory

Usage

calc_SourceDoseRate(
  measurement.date,
  calib.date,
  calib.dose.rate,
  calib.error,
  source.type = c("Sr-90", "Am-214", "Co-60", "Cs-137"),
  dose.rate.unit = c("Gy/s", "Gy/min"),
  predict = NULL
)

Value

Returns an S4 object of type RLum.Results. Slot data contains a list with the following structure:

$ dose.rate (data.frame)
.. $ dose.rate
.. $ dose.rate.error
.. $ date (corresponding measurement date)
$ parameters (list)
.. $ source.type
.. $ halflife
.. $ dose.rate.unit
$ call (the original function call)

The output should be accessed using the function get_RLum. A plot method of the output is provided via plot_RLum.

Arguments

measurement.date

character or Date (with default): Date of measurement in "YYYY-MM-DD" format. If no value is provided, the date will be set to today. The argument can be provided as vector.

calib.date

character or Date (required): date of source calibration in "YYYY-MM-DD" format.

calib.dose.rate

numeric (required): dose rate at date of calibration in Gy/s or Gy/min.

calib.error

numeric (required): error of dose rate at date of calibration Gy/s or Gy/min.

source.type

character (with default): specify irradiation source (Sr-90, Co-60, Cs-137, Am-214), see details for further information.

dose.rate.unit

character (with default): dose rate unit for input (one of Gy/min or Gy/s). The output is given in Gy/s as valid for the function convert_Second2Gray.

predict

integer (with default): option allowing to predict the dose rate of the source over time in days set by the provided value. Starting date is the value set with measurement.date, e.g., calc_SourceDoseRate(..., predict = 100) calculates the source dose rate for the next 100 days.

Function version

0.3.4

How to cite

Fuchs, M.C., Kreutzer, S., 2026. calc_SourceDoseRate(): Calculation of the source dose rate via the date of measurement. Function version 0.3.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.2.1. https://r-lum.github.io/Luminescence/

Author

Margret C. Fuchs, HZDR, Helmholtz-Institute Freiberg for Resource Technology (Germany)
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

References

NNDC, Brookhaven National Laboratory http://www.nndc.bnl.gov/

See Also

convert_Second2Gray, get_RLum, plot_RLum

Examples

Run this code

##(1) Simple function usage
##Basic calculation of the dose rate for a specific date
dose.rate <-  calc_SourceDoseRate(measurement.date = "2012-01-27",
                                  calib.date = "2014-12-19",
                                  calib.dose.rate = 0.0438,
                                  calib.error = 0.0019)

##show results
get_RLum(dose.rate)

##(2) Usage in combination with another function (e.g., convert_Second2Gray() )
## load example data
data(ExampleData.DeValues, envir = environment())

## use the calculated variable dose.rate as input argument
## to convert De(s) to De(Gy)
convert_Second2Gray(ExampleData.DeValues$BT998, dose.rate)

##(3) source rate prediction and plotting
dose.rate <-  calc_SourceDoseRate(measurement.date = "2012-01-27",
                                  calib.date = "2014-12-19",
                                  calib.dose.rate = 0.0438,
                                  calib.error = 0.0019,
                                  predict = 1000)
plot_RLum(dose.rate)

##(4) export output to a LaTeX table (example using the package 'xtable')
if (FALSE) {
xtable::xtable(get_RLum(dose.rate))
}

Run the code above in your browser using DataLab