Transforms a conventionally measured continuous-wave (CW) curve into a pseudo linearly modulated (pLM) curve using the equations given in Bulur (2000).
Arguments
- object
RLum.Data.Curve or data.frame (required): RLum.Data.Curve object or a
data.framewith measured curve data of type stimulation time (t) (object[, 1]) and measured counts (cts) (object[, 2]).- ...
currently not used.
Value
The function returns the same data type as the input data type with the transformed curve values (data.frame or RLum.Data.Curve).
Details
According to Bulur (2000) the curve data are transformed by introducing two
new parameters P (stimulation period) and u (transformed time):
$$P=2*max(t)$$ $$u=\sqrt{(2*t*P)}$$
The new count values are then calculated by $$ctsNEW = cts(u/P)$$
and the returned data.frame is produced by: data.frame(u,ctsNEW)
The output of the function can be further used for LM-OSL fitting.
Note
The transformation is recommended for curves recorded with a channel resolution of at least 0.05 s/channel.
How to cite
Kreutzer, S., Colombo, M., 2026. convert_CW2pLM(): Transform a CW-OSL curve into a pLM-OSL curve. Function version 0.4.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.2.0. https://r-lum.github.io/Luminescence/
References
Bulur, E., 2000. A simple transformation for converting CW-OSL curves to LM-OSL curves. Radiation Measurements 32, 141-145.
Further Reading
Bulur, E., 1996. An Alternative Technique For Optically Stimulated Luminescence (OSL) Experiment. Radiation Measurements 26, 701-709.
Author
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Marco Colombo, Institute of Geography, Heidelberg University (Germany)
, RLum Developer Team
Examples
##read curve from CWOSL.SAR.Data transform curve and plot values
data(ExampleData.BINfileData, envir = environment())
##read id for the 1st OSL curve
id.OSL <- CWOSL.SAR.Data@METADATA[CWOSL.SAR.Data@METADATA[,"LTYPE"] == "OSL","ID"]
##produce x and y (time and count data for the data set)
x<-seq(CWOSL.SAR.Data@METADATA[id.OSL[1],"HIGH"]/CWOSL.SAR.Data@METADATA[id.OSL[1],"NPOINTS"],
CWOSL.SAR.Data@METADATA[id.OSL[1],"HIGH"],
by = CWOSL.SAR.Data@METADATA[id.OSL[1],"HIGH"]/CWOSL.SAR.Data@METADATA[id.OSL[1],"NPOINTS"])
y <- unlist(CWOSL.SAR.Data@DATA[id.OSL[1]])
values <- data.frame(x,y)
##transform values
values.transformed <- convert_CW2pLM(values)
##plot
plot(values.transformed)