Converts RLum.Analysis and RLum.Data.Curve objects to RLum2Risoe.BINfileData objects
Source:R/convert_RLum2Risoe.BINfileData.R
convert_RLum2Risoe.BINfileData.RdThe functions converts RLum.Analysis and RLum.Data.Curve objects (or a list of such objects) to Risoe.BINfileData objects. The function intends to provide a minimum of compatibility between both formats. The created RLum.Analysis object can be later exported to a BIN-file using function write_R2BIN.
Arguments
- object
RLum.Analysis or RLum.Data.Curve (required): input object to be converted
- keep.position.number
logical (with default): keeps the original position number or re-calculate the numbers to avoid doubling
Value
The function returns a Risoe.BINfileData object.
Note
The conversion can be never perfect. The RLum objects may contain information which are
not part of the Risoe.BINfileData definition.
Author
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
How to cite
Kreutzer, S., 2026. convert_RLum2Risoe.BINfileData(): Converts RLum.Analysis and RLum.Data.Curve objects to RLum2Risoe.BINfileData objects. Function version 0.1.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.2.0. https://r-lum.github.io/Luminescence/
Examples
##simple conversion using the example dataset
data(ExampleData.RLum.Analysis, envir = environment())
convert_RLum2Risoe.BINfileData(IRSAR.RF.Data)
#>
#> [Risoe.BINfileData object]
#>
#> BIN/BINX version: 0
#> Object date: 20260312
#> User: 0
#> System ID: 0 (unknown)
#> Overall records: 2
#> Records type: RL (n = 2)
#> Position range: 0 : 0
#> Run range: 1 : 2
#> Set range: 0 : 0