Skip to contents

Conversion of single-grain data to multiple-grain data by adding signals from grains belonging to one disc (unique pairs of position, set and run).

Usage

convert_SG2MG(object, write_file = FALSE, ...)

Arguments

object

Risoe.BINfileData, character (required): Risoe.BINfileData object or BIN/BINX-file name.

write_file

logical (with default): whether the output should be written to a file (only considered if object is of type character). The multiple grain file will be written to a file of named after the original one with -SG appended to it.

...

further arguments passed down to read_BIN2R and write_R2BIN if object is a path to a file.

Value

A Risoe.BINfileData object. If write_file = TRUE an the input was a file path, a file is also written out to origin folder.

Function version

0.1.1

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Norbert Mercier, IRAMAT-CRP2A, UMR 5060, CNRS-Université Bordeaux Montaigne (France) , RLum Developer Team

How to cite

Kreutzer, S., Mercier, N., 2026. convert_SG2MG(): Converts Single-Grain Data to Multiple-Grain Data. Function version 0.1.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.2.1. https://r-lum.github.io/Luminescence/

Examples

## simple run
## (please not that the example is not using SG data)
data(ExampleData.BINfileData, envir = environment())
convert_SG2MG(CWOSL.SAR.Data)
#> 
#> [Risoe.BINfileData object]
#> 
#> 	BIN/BINX version:     03
#> 	Object date:          060920, 070920, 080920, 090920, 100920
#> 	User:                 Default
#> 	System ID:            0 (unknown)
#> 	Overall records:      720
#> 	Records type:         IRSL	(n = 24)
#> 	                      OSL	(n = 336)
#> 	                      TL	(n = 360)
#> 	Position range:       1 : 24
#> 	Run range:            1 : 8
#> 	Set range:            2 : 6