Learn R Programming

Luminescence (version 1.3.0)

convert_Second2Gray: Converting equivalent dose values from seconds (s) to Gray (Gy)

Description

Conversion of absorbed radiation dose in seconds (s) to the SI unit Gray (Gy) including error propagation. Normally used for equivalent dose data.

Calculation of De values from seconds (s) to Gray (Gy)

$$De [Gy] = De [s] * Dose Rate [Gy/s])$$

Provided calculation error propagation methods for error calculation (with 'se' as the standard error and 'DR' of the dose rate of the beta-source):

(1) omit (default)

$$se(De) [Gy] = se(De) [s] * DR [Gy/s]$$

In this case the standard error of the dose rate of the beta-source is treated as systematic (i.e. non-random), and error propagation is omitted. However, the error must be considered during calculation of the final age (cf. Aitken, 1985, pp. 242). This approach can be seen as method (2) (gaussian) for the case the (random) standard error of the beta-source calibration is 0. Which particular method is requested depends on the situation and cannot be prescriptive.

(2) gaussian error propagation

$$se(De) [Gy] = \sqrt{(DR [Gy/s] * se(De) [s])^2 + (De [s] * se(DR) [Gy/s])^2}$$

Applicable under the assumption that errors of De and se are uncorrelated.

(3) absolute error propagation

$$se(De) [Gy]= abs(DR [Gy/s] * se(De) [s]) + abs(De [s] * se(DR) [Gy/s])$$

Applicable under the assumption that errors of De and se are correlated.

Usage

convert_Second2Gray(
  data,
  dose.rate,
  error.propagation = c("omit", "gaussian", "absolute")
)

Value

Returns a data.frame with converted values.

Arguments

data

data.frame (required): input values, structure: data (values[,1]) and data error (values [,2]) are required.

dose.rate

RLum.Results, data.frame or numeric (required): for RLum.Results, it needs to be originated from calc_SourceDoseRate; for vector, dose rate and dose rate error (in Gy/s).

error.propagation

character (with default): error propagation method used for error calculation (omit, gaussian or absolute), see details for further information.

Function version

0.6.0

How to cite

Kreutzer, S., Dietze, M., Fuchs, M.C., 2026. convert_Second2Gray(): Converting equivalent dose values from seconds (s) to Gray (Gy). Function version 0.6.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Michael Dietze, GFZ Potsdam (Germany)
Margret C. Fuchs, HZDR, Helmholtz-Institute Freiberg for Resource Technology (Germany) , RLum Developer Team

References

Aitken, M.J., 1985. Thermoluminescence dating. Academic Press.

See Also

calc_SourceDoseRate

Examples

Run this code
## load De data from the example data help file
data(ExampleData.DeValues, envir = environment())

##(A) for known source dose rate at date of measurement
## - convert De(s) to De(Gy)
convert_Second2Gray(ExampleData.DeValues$BT998, c(0.0438, 0.0019))

##(B) for source dose rate calibration data
## - calculate source dose rate first
dose.rate <-  calc_SourceDoseRate(measurement.date = "2012-01-27",
                                  calib.date = "2014-12-19",
                                  calib.dose.rate = 0.0438,
                                  calib.error = 0.0019)
# read example data
data(ExampleData.DeValues, envir = environment())

# apply dose.rate to convert De(s) to De(Gy)
convert_Second2Gray(ExampleData.DeValues$BT998, dose.rate)

Run the code above in your browser using DataLab