View source: R/correct_PMTLinearity.R
| correct_PMTLinearity | R Documentation |
Correct dead-time (also linearity) of PMT counts to avoid saturation effects, depending on pulse-pair-resolution of individual PMTs.
correct_PMTLinearity(object, PMT_pulse_pair_resolution = NULL)
object |
RLum.Analysis RLum.Data.Curve (required): object with records to correct; can be a list of such objects |
PMT_pulse_pair_resolution |
numeric (with default): pulse-pair resolution
in ns. Values can be found on the PMT datasheets. If |
We correct for count linearity using a well-known formula that can be found for example in the Hamamatsu Photomultiplier handbook (Hamamatsu Photonics K.K., 2017):
N = \frac{M}{1 - Mt}
where N (in s^{-1}) is the true count rate, M (in s^{-1}) the measured count rate,
and t (in s) the pulse pair resolution.
Returns the same type of object type as object.
0.1.1
Kreutzer, S., Mittelstrass, D., 2026. correct_PMTLinearity(): Dead-time (linearity) Correction for Photomultiplier tubes (PMT). Function version 0.1.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
This function is an adaptation of core from the R package 'OSLdecomposition'.
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Dirk Mittelstrass, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
, RLum Developer Team
Hamamatsu Photonics K.K., 2017. Photomultiplier Tubes: Basics and Applications, 4th edition. ed. Hamamatsu.
Mittelstraß, D., Kreutzer, S., Schmidt, C., 2022. OSLdecomposition: Signal component analysis for optically stimulated luminescence. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.32614/CRAN.package.OSLdecomposition")}
o <- set_RLum("RLum.Data.Curve")
correct_PMTLinearity(o, PMT_pulse_pair_resolution = 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.