nls function with the port algorithm.fit_CWCurve(values, n.components.max, fit.failure_threshold = 3,
fit.trace = FALSE, fit.calcError = FALSE, LED.power = 36,
LED.wavelength = 470, log = "", cex.global = 0.6, main = "CW-OSL Curve Fit",
sample_code = "Default", ylab, xlab, output.path, output.terminal = TRUE,
output.terminalAdvanced = TRUE, output.plot = TRUE)RLum.Data.Curve or data.frame
(required): x, y data of measured values (time and counts). See examples.output.terminal = TRUE.
If output.terminal = FALSE no advanced output is possible.output.path is set.RLum.Results objectRLum.Results object is returned.
fit: an nls object ($fit) for which generic R functions
are provided, e.g. summary, confint, profile.
For more details, see nls.
output.table: a data.frame containing the summarized
parameters including the error
component.contribution.matrix: matrix containing the values
for the component to sum contribution plot
($component.contribution.matrix).confint. Due to considerable calculation time, this option is
deactived by default. In addition, the error for the components can be
estimated by using internal R functions like summary.
See the nls help page for more information.
For details on the nonlinear regression in R, see Ritz & Streibig (2008).fit_LMCurve, plot,nls,
RLum.Data.Curve , RLum.Results ,
get_RLum.Results##load data
data(ExampleData.CW_OSL_Curve, envir = environment())
##fit data
fit <- fit_CWCurve(values = ExampleData.CW_OSL_Curve,
main = "CW Curve Fit",
n.components.max = 4,
log = "x")Run the code above in your browser using DataLab