Learn R Programming

Luminescence (version 1.3.0)

length_RLum: Length retrieval function for RLum-class objects

Description

The function provides a generalised access point for specific RLum objects. Depending on the input object, the corresponding function will be selected.

Usage

length_RLum(object)

# S4 method for RLum.Analysis length_RLum(object)

# S4 method for RLum.Data.Curve length_RLum(object)

# S4 method for RLum.Results length_RLum(object)

Value

An integer indicating the length of the object.

Arguments

object

RLum (required): S4 object of class RLum

Functions

  • length_RLum(RLum.Analysis): Returns the number of records stored in the object.

  • length_RLum(RLum.Data.Curve): Returns the length of the curve object, which is the maximum of the value time/temperature of the curve (corresponding to the stimulation length).

  • length_RLum(RLum.Results): Returns the number of stored data elements.

Function version

0.1.0

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

How to cite

Kreutzer, S., 2026. length_RLum(): Length retrieval function for RLum-class objects. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/

See Also

RLum.Data.Curve, RLum.Data.Image, RLum.Data.Spectrum, RLum.Analysis, RLum.Results