| melt_RLum | R Documentation |
Melt RLum-class objects into a flat data.frame
melt_RLum(object, ...)
## S4 method for signature 'list'
melt_RLum(object, ...)
## S4 method for signature 'RLum.Analysis'
melt_RLum(object)
## S4 method for signature 'RLum.Data.Curve'
melt_RLum(object)
object |
RLum (required):
S4 object of class |
... |
further arguments passed to the specific class method |
A flat data.frame.
melt_RLum(list): Returns a list of melted RLum objects; non-RLum objects are silently
removed.
melt_RLum(RLum.Analysis): Melts RLum.Analysis objects into a flat data.frame with columns
X, Y, TYPE, UID, to be used in combination with other packages
such as ggplot2.
melt_RLum(RLum.Data.Curve): Melts RLum.Data.Curve objects into a flat data.frame with columns
X, Y, TYPE, UID, to be used in combination with other packages
such as ggplot2.
0.1.0
Kreutzer, S., 2026. melt_RLum(): Melt RLum-class objects into a flat data.frame. Function version 0.1.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum.Data.Curve, RLum.Analysis
data(ExampleData.XSYG, envir = environment())
melt_RLum(OSL.SARMeasurement[[2]][[1]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.