| merge_RLum | R Documentation |
The function provides a generalised access point for merging specific
RLum objects. Depending on the input object, the
corresponding merge function will be selected. Allowed arguments can be
found in the documentation of each merge function.
Empty list elements (NULL) are automatically removed from the input list.
| object | corresponding merge function | |
| RLum.Data.Curve | -> | merge_RLum.Data.Curve |
| RLum.Data.Spectrum | -> | merge_RLum.Data.Spectrum |
| RLum.Analysis | -> | merge_RLum.Analysis |
| RLum.Results | -> | merge_RLum.Results |
merge_RLum(object, ...)
object |
list of RLum (required):
list of S4 object of class |
... |
further arguments that one might want to pass to the specific merge function |
Returns an RLum.Analysis object of class if any of the inputs is of that class. Otherwise, it returns an object of the same type as the input.
0.1.4
Kreutzer, S., 2026. merge_RLum(): General merge function for RLum-class objects. Function version 0.1.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
So far merging of RLum.Data.Image objects is not supported.
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum.Data.Curve, RLum.Data.Spectrum, RLum.Analysis, RLum.Results
##Example based using data and from the calc_CentralDose() function
##load example data
data(ExampleData.DeValues, envir = environment())
##apply the central dose model 1st time
temp1 <- calc_CentralDose(ExampleData.DeValues$CA1)
##apply the central dose model 2nd time
temp2 <- calc_CentralDose(ExampleData.DeValues$CA1)
##merge the results and store them in a new object
temp.merged <- get_RLum(merge_RLum(object = list(temp1, temp2)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.