View source: R/merge_RLum.Analysis.R
| merge_RLum.Analysis | R Documentation |
This function simply allows to merge RLum.Analysis objects. Moreover, other RLum.Data objects can be added to an existing RLum.Analysis object. Supported objects to be added are: RLum.Data.Curve, RLum.Data.Spectrum and RLum.Data.Image.
merge_RLum.Analysis(object, ...)
object |
list of RLum.Analysis (required):
list of S4 objects of class |
... |
currently not used. |
Returns an RLum.Analysis object ordered according to the order provided with the input list.
0.2.4
Kreutzer, S., 2026. merge_RLum.Analysis(): Merge function for RLum.Analysis S4 class objects. Function version 0.2.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
The information for the slot 'protocol' is taken from the first RLum.Analysis object in the input list. Therefore at least one object of type RLum.Analysis has to be provided.
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
merge_RLum, RLum.Analysis, RLum.Data.Curve, RLum.Data.Spectrum, RLum.Data.Image, RLum
##merge different RLum objects from the example data
data(ExampleData.RLum.Analysis, envir = environment())
data(ExampleData.BINfileData, envir = environment())
object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)
curve <- get_RLum(object)[[2]]
temp.merged <- merge_RLum.Analysis(list(curve, IRSAR.RF.Data, IRSAR.RF.Data))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.