Learn R Programming

Luminescence (version 1.3.0)

merge_RLum.Results: Merge function for RLum.Results S4-class objects

Description

Function merges objects of class RLum.Results. The slots in the objects are combined depending on the object type, e.g., for data.frame and matrix rows are appended.

Usage

merge_RLum.Results(objects, flatten = TRUE)

Arguments

objects

list (required): a list of RLum.Results objects

flatten

logical (with default): whether list elements should be flattened before merging.

Function version

0.3

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

How to cite

Kreutzer, S., 2026. merge_RLum.Results(): Merge function for RLum.Results S4-class objects. Function version 0.3. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/

Details

Elements are appended where possible and attributes are preserved if not of similar name as the default attributes of, e.g., a data.frame