model_LuminescenceSignals: Model Luminescence Signals (wrapper)
Usage
model_LuminescenceSignals(model, sequence, lab.dose_rate = 1, simulate_sample_history = FALSE, plot = TRUE, verbose = TRUE, show.structure = FALSE, ...)
Arguments
model
character (required): set model to be used. Available models are:
"Bailey2001", "Bailey2002", "Bailey2004", "Pagonis2007", "Pagonis2008"sequence
list (required): set sequence to model as list or as *.seq file from the
Riso sequence editor. To simulate SAR measurements there is an extra option to set the sequence list (cf. details).lab.dose_rate
numeric (with default): laboratory dose rate in XXX
Gy/s for calculating seconds into Gray in the *.seq file.simulate_sample_history
logical (with default): FALSE (with default): simulation begins at laboratory conditions, TRUE: simulations begins at crystallization (all levels 0)
processplot
logical (with default): Enables or disables plot outputverbose
logical (with default): Verbose mode on/offshow.structure
logical (with default): Shows the structure of the result.
Recommended to show record.id to analyse concentrations....
further arguments and graphical parameters passed to
plot.default. See details for further information. Function version
0.1.0 (2016-05-02 09:36:06)