| normalise_RLum | R Documentation |
The function provides a generalised access point for specific
RLum objects. Depending on the input object, the corresponding
function will be selected. The normalisation is performed in the internal
function .normalise_curve().
normalise_RLum(object, norm = TRUE, ...)
## S4 method for signature 'list'
normalise_RLum(object, norm = TRUE, ...)
## S4 method for signature 'RLum.Analysis'
normalise_RLum(object, norm = TRUE, ...)
## S4 method for signature 'RLum.Data.Curve'
normalise_RLum(object, norm)
## S4 method for signature 'RLum.Data.Image'
normalise_RLum(object, norm = TRUE, global = TRUE)
## S4 method for signature 'RLum.Data.Spectrum'
normalise_RLum(object, norm = TRUE)
object |
RLum (required):
S4 object of class |
norm |
logical character (required):
if logical, whether curve normalisation should occur; alternatively, one
of |
... |
further arguments passed to the specific class method |
global |
logical (*with default): this defines whether the normalisation
is applied globally (same to all) or locally, in which case each frame has its
own normalisation. If Normalise RLum.Data.Image objects to value set via
the argument |
The norm argument normalises all count values. The following options are
supported:
norm = TRUE or norm = "max": Curve values are normalised to the highest
count value in the curve
norm = "min": Curve values are normalised to the smallest count value
in the curve
norm = "first": Curve values are normalised to the first count value.
norm = "last": Curve values are normalised to the last count value
(this can be useful in particular for radiofluorescence curves)
norm = "huot": Curve values are normalised as suggested by Sébastien Huot
via GitHub:
y = (observed - median(background)) / (\max(observed) - median(background))
The background of the curve is defined as the last 20% of the count values of a curve.
norm = "intensity": Curve values are normalised to the channel length.
norm = 2.2: Curve values are normalised to a positive number (e.g., 2.2).
An object of the same type as the input object provided.
normalise_RLum(list): Returns a list of RLum.Data objects that had been passed to
normalise_RLum
normalise_RLum(RLum.Analysis): Normalisation of RLum.Data records contained in the input object.
normalise_RLum(RLum.Data.Curve): Normalise RLum.Data.Curve objects to value set via
the argument norm
normalise_RLum(RLum.Data.Image): Normalise RLum.Data.Image objects to value set via
the argument norm.
normalise_RLum(RLum.Data.Spectrum): Normalise RLum.Data.Spectrum objects to value set via
the argument norm
0.1.3
Kreutzer, S., 2026. normalise_RLum(): Normalisation of RLum-class objects. Function version 0.1.3. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum.Data.Curve, RLum.Analysis, RLum.Data.Spectrum, RLum.Data.Image
## load example data
data(ExampleData.CW_OSL_Curve, envir = environment())
## create RLum.Data.Curve object from this example
curve <-
set_RLum(
class = "RLum.Data.Curve",
recordType = "OSL",
data = as.matrix(ExampleData.CW_OSL_Curve)
)
## plot data without and with smoothing
plot_RLum(curve)
plot_RLum(normalise_RLum(curve))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.