Learn R Programming

Luminescence (version 1.3.1)

plot_DRCSummary: Create a Dose-Response Curve Summary Plot

Description

While analysing OSL SAR or pIRIR-data the view on the data is usually limited to one dose-response curve (DRC) at the time for one aliquot. This function overcomes this limitation by plotting all DRCs from an RLum.Results object created by analyse_SAR.CWOSL in one single plot.

If you want plot your DRC on an energy scale (dose in Gy), you can either use option source_dose_rate or perform your SAR analysis with the dose points in Gy (better axis scaling).

Usage

plot_DRCSummary(
  object,
  source_dose_rate = NULL,
  sel_curves = NULL,
  show_dose_points = FALSE,
  show_natural = FALSE,
  n = 51L,
  ...
)

Value

An RLum.Results object is returned:

Slot: @data

OBJECTTYPECOMMENT
resultsdata.framewith dose and LxTx values
dataRLum.Resultsoriginal input data

Slot: @info

OBJECTTYPECOMMENT
callcallthe original function call
argslistarguments of the original function call

Note: If the input object is a list a list of RLum.Results objects is returned.

Arguments

object

RLum.Results (required): input object created by analyse_SAR.CWOSL. The input object can be provided as list.

source_dose_rate

numeric (optional): allows to modify the axis and show values in Gy, instead seconds. Only a single numerical value is allowed.

sel_curves

numeric (optional): id of the curves to be plotted in its occurring order. A sequence can be provided for selecting, e.g., only every 2nd curve from the input object.

show_dose_points

logical (with default): enable/disable plotting of dose points in the graph.

show_natural

logical (with default): enable/disable the plot of the natural Lx/Tx values.

n

integer (with default): number of x-values used to evaluate one curve object. Large numbers slow down the plotting process and are usually not needed.

...

further arguments and graphical parameters to control the plot output. Supported are: main, xlab, ylab, xlim, ylim, lty, lwd, pch, col.pch, col.lty, mtext, and pt.cex (point size).

Function version

0.2.5

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Christoph Burow, University of Cologne (Germany) , RLum Developer Team

How to cite

Kreutzer, S., Burow, C., 2026. plot_DRCSummary(): Create a Dose-Response Curve Summary Plot. Function version 0.2.5. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/

See Also

RLum.Results, analyse_SAR.CWOSL

Examples

Run this code

#load data example data
data(ExampleData.BINfileData, envir = environment())

#transform the values from the first position in a RLum.Analysis object
object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)

## perform SAR analysis
results <- analyse_SAR.CWOSL(
    object,
    signal_integral = 1:2,
    background_integral = 900:1000,
    plot = FALSE
)

##plot only DRC
plot_DRCSummary(results)

Run the code above in your browser using DataLab