Plots the equivalent dose (\(D_e\)) in dependency of the chosen signal integral
(cf. Bailey et al., 2003). The function is simply passing several arguments
to the function plot and the used analysis functions and runs it in a loop.
Example: legend.pos for legend position, legend for legend text.
plot_DetPlot(
object,
signal_integral,
background_integral,
method = "shift",
signal_integral.seq = NULL,
integral_input = c("channel", "measurement"),
analyse_function = c("analyse_SAR.CWOSL", "analyse_pIRIRSequence"),
analyse_function.control = list(),
n.channels = NULL,
show_ShineDownCurve = TRUE,
respect_RC.Status = FALSE,
multicore = TRUE,
verbose = TRUE,
plot = TRUE,
...
)A plot and an RLum.Results object with the produced \(D_e\) values
@data:
| Object | Type | Description |
De.values | data.frame | table with De values |
signal_integral.seq | numeric | integral sequence used for the calculation |
@info:
| Object | Type | Description |
| call | call | the original function call |
RLum.Analysis (required): input object containing data for analysis. Can be provided as a list of such objects.
integer (required): vector of channels for the signal integral.
integer (required): vector of channels for the background integral.
character (with default): method applied for constructing the De(t) plot.
shift (the default): the chosen signal integral is shifted the shine down curve,
expansion: the chosen signal integral is expanded each time by its length
numeric (optional): argument to provide an own signal integral sequence for constructing the De(t) plot
character (with default):
input type for signal_integral, one of "channel" (default) or
"measurement". If set to "measurement", the best matching channels
corresponding to the given time range (in seconds) are selected.
character (with default): name of the analyse function to be called. Supported functions are: analyse_SAR.CWOSL, analyse_pIRIRSequence
list (optional):
selected arguments to be passed to the supported analyse functions
(analyse_SAR.CWOSL, analyse_pIRIRSequence).
The arguments must be provided as named list, e.g.,
list(dose.points = c(0, 10, 20, 30, 0, 10) will set the regeneration dose
points.
integer (optional): number of channels used for the De(t) plot. If nothing is provided all De-values are calculated and plotted until the start of the background integral.
logical (with default): enable/disable shine down curve in the plot output.
logical (with default): remove De values with 'FAILED' RC.Status from the plot (cf. analyse_SAR.CWOSL and analyse_pIRIRSequence).
logical (with default):
enable/disable multi core calculation if object is a list of
RLum.Analysis objects. Can be an integer specifying
the number of cores to use.
logical (with default): enable/disable output to the terminal.
logical (with default): enable/disable the plot output. Disabling the plot is useful in cases where the output need to be processed differently.
further arguments and graphical parameters passed to
plot.default, analyse_SAR.CWOSL and analyse_pIRIRSequence (see details for further information).
Plot control parameters are: ylim, xlim, ylab, xlab, main, pch, mtext, cex, legend,
legend.text, legend.pos
0.1.11
Kreutzer, S., 2026. plot_DetPlot(): Create De(t) plot. Function version 0.1.11. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
The original method presented by Bailey et al. (2003) shifts the signal
integrals and slightly extends them to account for changes in counting
statistics, producing sequences such as c(1:3, 3:5, 5:7).
Here we provide an additional method that expands the signal integral
consecutively by its chosen length, producing sequences like
c(1:3, 1:5, 1:7) instead.
Note that in both cases the integral limits overlap. The finally applied limits are part of the function output.
analyse_function.control
The argument analyse_function.control currently supports the following arguments:
sequence.structure, dose.points, dose_rate_source, mtext.outer,
fit.method, fit.force_through_origin, trim_channels, plot and
plot_singlePanels.
Bailey, R.M., Singarayer, J.S., Ward, S., Stokes, S., 2003. Identification of partial resetting using De as a function of illumination time. Radiation Measurements 37, 511-518. doi:10.1016/S1350-4487(03)00063-5
plot, analyse_SAR.CWOSL, analyse_pIRIRSequence
if (FALSE) {
##load data
##ExampleData.BINfileData contains two BINfileData objects
##CWOSL.SAR.Data and TL.SAR.Data
data(ExampleData.BINfileData, envir = environment())
##transform the values from the first position in a RLum.Analysis object
object <- Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos=1)
plot_DetPlot(
object,
signal_integral = 1:3,
background_integral = 900:1000,
n.channels = 5)
}
Run the code above in your browser using DataLab