Skip to contents

The function calls object specific plot functions for RLum S4 class objects.

Usage

plot_RLum(object, ...)

Arguments

object

RLum (required): object of class RLum or a list of such objects. If a list is provided, the function tries to plot every object in the list according to its RLum class, after removing non-RLum objects.

...

further arguments and graphical parameters to pass to the specific plot functions. The only arguments that are supported directly are main (plot title) and mtext (plot subtitle). Here main can be provided as a list and the arguments in the list will dispatched to the plots if object is of type list as well.

Value

Produces a plot depending on the input object.

Details

The function provides a generalised access point for plotting various RLum objects. Depending on the input object, the corresponding plot function will be selected. Allowed arguments can be found in the documentations of each plot function.

objectcorresponding plot functionRLum.Data.Curve
plot_RLum.Data.CurveRLum.Data.Spectrumplot_RLum.Data.Spectrum
RLum.Data.Imageplot_RLum.Data.ImageRLum.Analysis
plot_RLum.AnalysisRLum.Resultsplot_RLum.Results

Function version

0.5

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Marco Colombo, Institute of Geography, Heidelberg University (Germany)
, RLum Developer Team

How to cite

Kreutzer, S., Colombo, M., 2026. plot_RLum(): General plot function for RLum S4 class objects. Function version 0.5. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.2.0. https://r-lum.github.io/Luminescence/

Examples

#load Example data
data(ExampleData.CW_OSL_Curve, envir = environment())

#transform data.frame to RLum.Data.Curve object
temp <- as(ExampleData.CW_OSL_Curve, "RLum.Data.Curve")

#plot RLum object
plot_RLum(temp)