The function provides a standardised plot output for curve data of an RLum.Data.Curve S4-class object.
plot_RLum.Data.Curve(
object,
par.local = TRUE,
norm = FALSE,
smooth = FALSE,
auto_scale = FALSE,
interactive = FALSE,
...
)Returns a plot.
RLum.Data.Curve (required): S4 object of class RLum.Data.Curve
logical (with default):
use local graphical parameters for plotting, e.g. the plot is shown in one
column and one row. If par.local = FALSE, global parameters are inherited.
logical character (with default): whether curve
normalisation should occur (FALSE by default). Alternatively, the function
offers modes "max" (used with TRUE), "last" and "huot", see details.
logical (with default):
provides automatic curve smoothing based on the internal function .smoothing
logical (with default): if activated, auto scales xlim or ylim
to the extent of the other. If both are set, the auto-scaling is skipped.
logical (with default): enables/disables interactive plotting mode using plotly::plot_ly
further arguments and graphical parameters that will be passed to graphics::plot.default and graphics::par
0.4.0
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
Kreutzer, S., 2026. plot_RLum.Data.Curve(): Plot function for an RLum.Data.Curve S4 class object. Function version 0.4.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/
Only single curve data can be plotted with this function. Arguments according to plot.
Curve normalisation
The argument norm normalises all count values. To date the following
options are supported:
norm = TRUE or norm = "max": Curve values are normalised to the highest
count value in the curve
norm = "min": Curve values are normalised to the smallest count value
in the curve
norm = "first": Curve values are normalised to the very first count value
norm = "last": Curve values are normalised to the last count value
(this can be useful in particular for radiofluorescence curves)
norm = "huot": Curve values are normalised as suggested by Sébastien Huot
via GitHub:
$$
y = (observed - median(background)) / (\max(observed) - median(background))
$$
The background of the curve is defined as the last 20% of the count values of a curve.
norm = "intensity": Curve values are normalised to the channel length.
norm = 2.2: Curve values are normalised to a positive number (e.g., 2.2).
plot, plot_RLum
##plot curve data
#load Example data
data(ExampleData.CW_OSL_Curve, envir = environment())
#transform data.frame to RLum.Data.Curve object
temp <- as(ExampleData.CW_OSL_Curve, "RLum.Data.Curve")
#plot RLum.Data.Curve object
plot_RLum.Data.Curve(temp)
Run the code above in your browser using DataLab