The function provides a standardised plot output for spectrum data of an
RLum.Data.Spectrum class object. The purpose of this function is to
provide easy and straightforward spectra plotting, not a fully customised
access to all plot parameters. If this is wanted, standard R plot
functionality should be used instead.
Matrix structure
(cf. RLum.Data.Spectrum)
rows (x-values): wavelengths/channels (xlim, xlab)
columns (y-values): time/temperature (ylim, ylab)
cells (z-values): count values (zlim, zlab)
Note: This nomenclature is valid for all plot types of this function!
Nomenclature for value limiting
xlim: Limits values along the wavelength axis
ylim: Limits values along the time/temperature axis
zlim: Limits values along the count value axis
Details on the plot functions
Spectrum is visualised as 3D or 2D plot. Both plot types are based on
internal R plot functions.
plot.type = "persp"
Arguments that will be passed to graphics::persp:
shade: default is 0.4
phi: default is 15
theta: default is -30
lphi: default is 15
ltheta: default is -30
expand: default is 1
axes: default is TRUE
box: default is TRUE; accepts "alternate" for a custom plot design
ticktype: default is detailed, r: default is 10
Note: Further parameters can be adjusted via par. For example
to set the background transparent and reduce the thickness of the lines use:
par(bg = NA, lwd = 0.7) before the function call.
plot.type = "single"
Per frame a single curve is returned. Frames are time or temperature
steps.
-frames: pick the frames to be plotted (depends on the binning!). Check without
this setting before plotting.
plot.type = "multiple.lines"
All frames plotted in one frame.
-frames: pick the frames to be plotted (depends on the binning!). Check without
this setting before plotting.
plot.type = "image" or plot.type = "contour"
These plot types use the R functions graphics::image or graphics::contour.
The advantage is that many plots can be arranged conveniently using standard
R plot functionality. If plot.type = "image" a contour is added by default,
which can be disabled using the argument contour = FALSE to add own contour
lines of choice.
plot.type = "transect"
Depending on the selected wavelength/channel range a transect over the
time/temperature (y-axis) will be plotted along the wavelength/channels
(x-axis). If the range contains more than one channel, values (z-values) are
summed up. To select a transect use the xlim argument, e.g.
xlim = c(300,310) plot along the summed up count values of channel
300 to 310.
add: default is FALSE: adds the plot to an existing plot
smooth: default is FALSE: performs a simple curve smoothing
transect_mode: default is sum: sets the integration mode for the transect along the
wavelength axis. Other allowed values are mean, mean, min, max
Further arguments that will be passed (depending on the plot type)
xlab, ylab, zlab, xlim, ylim, zlim, main, mtext,
box, pch, type ("single", "multiple.lines", "interactive"),
col, border, lwd, bty, showscale ("interactive", "image")
contour, contour.col ("image"), labcex ("image", "contour"),
n_breaks ("image"), legend (TRUE/FALSE),
legend.pos ("image"), legend.horiz (TRUE/FALSE | "image")