Learn R Programming

Luminescence (version 1.3.0)

plot_RLum.Results: Plot function for an RLum.Results S4 class object

Description

The function provides a standardised plot output for data of an RLum.Results S4 class object, redirecting to specialised functions if necessary.

Usage

plot_RLum.Results(object, single = TRUE, ...)

Value

Returns multiple plots.

Arguments

object

RLum.Results (required): S4 object of class RLum.Results.

single

logical (with default): single plot output (TRUE/FALSE) to allow for plotting the results in as few plot windows as possible.

...

further arguments and graphical parameters will be passed to the plot function.

Function version

0.2.2

Author

Christoph Burow, University of Cologne (Germany)
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

How to cite

Burow, C., Kreutzer, S., 2026. plot_RLum.Results(): Plot function for an RLum.Results S4 class object. Function version 0.2.2. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/

Details

The function may produce multiple plots, in which case a file output is recommended (e.g., pdf).

See Also

plot, plot_RLum

Examples

Run this code

###load data
data(ExampleData.DeValues, envir = environment())

# apply the un-logged minimum age model
mam <- calc_MinDose(data = ExampleData.DeValues$CA1, sigmab = 0.2, log = TRUE, plot = FALSE)

##plot
plot_RLum.Results(mam)

# estimate the number of grains on an aliquot
grains<- calc_AliquotSize(grain.size = c(100,150), sample.diameter = 1, plot = FALSE, MC.iter = 100)

##plot
plot_RLum.Results(grains)

Run the code above in your browser using DataLab