Learn R Programming

Luminescence (version 1.3.0)

read_HeliosOSL2R: Import Luminescence Data from Helios Luminescence Reader

Description

Import of files with .osl extension produced by the zero rad Helios luminescence reader and conversion to RLum.Analysis objects.

Usage

read_HeliosOSL2R(file, verbose = TRUE, ...)

Value

A RLum.Analysis object. Results are returned as a list when multiple files are processed or file is a list.

Arguments

file

character, list (required): name of one or multiple .osl files (URLs are supported); it can be the path to a directory, in which case the function tries to detect and import all .osl files found in the directory.

verbose

logical (with default): enable/disable output to the terminal.

...

not in use, for compatibility reasons only

Function version

0.1.1

Author

Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team

How to cite

Kreutzer, S., 2026. read_HeliosOSL2R(): Import Luminescence Data from Helios Luminescence Reader. Function version 0.1.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., Boer, A.d., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.0. https://r-lum.github.io/Luminescence/

See Also

RLum.Data.Curve, RLum.Analysis

Examples

Run this code
file <- system.file("extdata/HeliosOSL_Example.osl", package = "Luminescence")
read_HeliosOSL2R(file)

Run the code above in your browser using DataLab