| read_PSL2R | R Documentation |
This function provides an import routine for the SUERC portable OSL Reader PSL format (measurement data and sequence). PSL files are just plain text and can be viewed with any text editor. Due to the formatting of PSL files, this import function relies heavily on regular expression to find and extract all relevant information. See note.
read_PSL2R(
file,
drop_bg = FALSE,
as_decay_curve = TRUE,
smooth = FALSE,
merge = FALSE,
pattern = "\\.psl$",
verbose = TRUE,
...
)
file |
character (required): name of one or multiple PSL files (URLs are supported); it can be the path to a directory, in which case the function tries to detect and import all PSL files found in the directory. |
drop_bg |
logical (with default):
|
as_decay_curve |
logical (with default):
Portable OSL Reader curves are often given as cumulative light sum curves.
Use |
smooth |
logical (with default):
|
merge |
logical (with default):
|
pattern |
character (with default): regular expression pattern passed to list.files to construct a list of files to read (used only when a path is provided). |
verbose |
logical (with default): enable/disable output to the terminal. |
... |
currently not used. |
Returns an S4 RLum.Analysis object containing
RLum.Data.Curve objects for each curve. Results are
returned as a list when multiple files are processed or file is a list.
0.1.2
Burow, C., Kreutzer, S., 2026. read_PSL2R(): Import SUERC portable OSL Reader PSL files into R. Function version 0.1.2. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Because this function relies heavily on regular expressions to parse
PSL files it is currently only in beta status. If the routine fails to import
a specific PSL file please report to <christoph.burow@gmx.net> so the
function can be updated.
Christoph Burow, University of Cologne (Germany)
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
, RLum Developer Team
RLum.Analysis, RLum.Data.Curve, RLum.Data.Curve
# (1) Import PSL file to R
file <- system.file("extdata", "DorNie_0016.psl", package = "Luminescence")
psl <- read_PSL2R(file, drop_bg = FALSE, as_decay_curve = TRUE, smooth = TRUE, merge = FALSE)
print(str(psl, max.level = 3))
plot(psl, combine = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.