| read_RF2R | R Documentation |
Import files produced by the IR-RF 'ImageJ' macro (SR-RF.ijm;
Mittelstraß and Kreutzer, 2021) into R and create a list of
RLum.Analysis objects.
read_RF2R(file, verbose = TRUE, ...)
file |
character (required): name of one or multiple RF files (URLs are supported); it can be the path to a directory, in which case the function tries to detect and import all RF files found in the directory. |
verbose |
logical (with default): enable/disable output to the terminal. |
... |
not used, only for compatible reasons |
The results of spatially resolved IR-RF data are summarised in so-called RF-files (Mittelstraß and Kreutzer, 2021). The output of the function can be passed to function analyse_IRSAR.RF.
Returns an S4 RLum.Analysis object containing
RLum.Data.Curve objects for each curve. Results are
returned as a list when multiple files are processed or file is a list.
The header may contain key = "value" pairs, which will be stored in the
info slot; incomplete pairs are silently dropped.
0.1.4
Kreutzer, S., Colombo, M., 2026. read_RF2R(): Import RF-files to R. Function version 0.1.4. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany)
Marco Colombo, Institute of Geography, Heidelberg University (Germany)
, RLum Developer Team
Mittelstraß, D., Kreutzer, S., 2021. Spatially resolved infrared radiofluorescence: single-grain K-feldspar dating using CCD imaging. Geochronology 3, 299–319. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5194/gchron-3-299-2021")}
RLum.Analysis, RLum.Data.Curve, analyse_IRSAR.RF
file <- system.file("extdata", "RF_file.rf", package = "Luminescence")
object <- read_RF2R(file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.