| read_TIFF2R | R Documentation |
Simple wrapper around tiff::readTIFF to import TIFF images and TIFF image stacks to be further processed within the 'Luminescence' package.
read_TIFF2R(file, merge2stack = FALSE, verbose = TRUE, ...)
file |
character (required): name of the TIFF file to read (URLs are supported). |
merge2stack |
logical (with default): if |
verbose |
logical (with default): enable/disable output to the terminal. |
... |
not in use, for compatibility reasons only |
Returns an RLum.Data.Image object. Results are
returned as a list when multiple files are processed or file is a list.
0.2.1
Kreutzer, S., 2026. read_TIFF2R(): Import TIFF Image Data into R. Function version 0.2.1. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
tiff::readTIFF, RLum.Data.Image
## use system file
file <- system.file("extdata", "TIFFfile.tif", package = "Luminescence")
## import image
image <- read_TIFF2R(file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.