| structure_RLum | R Documentation |
The function provides a generalised access point for specific RLum objects. Depending on the input object, the corresponding function will be selected.
structure_RLum(object, ...)
## S4 method for signature 'list'
structure_RLum(object, ...)
## S4 method for signature 'RLum.Analysis'
structure_RLum(object, fullExtent = FALSE)
object |
RLum (required):
S4 object of class |
... |
further arguments passed to the specific class method |
fullExtent |
logical (with default):
extends the returned |
Returns a data.frame with structure of the object.
structure_RLum(list): Returns a list of data frames containing the structure of each RLum
object in the input list.
structure_RLum(RLum.Analysis): Returns the structure of an RLum.Analysis object.
0.2.0
Kreutzer, S., 2026. structure_RLum(): General structure function for RLum-class objects. Function version 0.2.0. In: Kreutzer, S., Burow, C., Dietze, M., Fuchs, M.C., Schmidt, C., Fischer, M., Friedrich, J., Mercier, N., Philippe, A., Riedesel, S., Autzen, M., Mittelstrass, D., Gray, H.J., Galharret, J., Colombo, M., Steinbuch, L., de Boer, A., Bluszcz, A., 2026. Luminescence: Comprehensive Luminescence Dating Data Analysis. R package version 1.3.1. https://r-lum.github.io/Luminescence/
Sebastian Kreutzer, F2.1 Geophysical Parametrisation/Regionalisation, LIAG - Institute for Applied Geophysics (Germany) , RLum Developer Team
RLum.Data.Curve, RLum.Data.Image, RLum.Data.Spectrum, RLum.Analysis, RLum.Results
## load example data
data(ExampleData.XSYG, envir = environment())
## show structure
structure_RLum(OSL.SARMeasurement$Sequence.Object)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.